Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitaly.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohn Cai <jcai@gitlab.com>2019-01-30 22:00:00 +0300
committerJohn Cai <jcai@gitlab.com>2019-01-30 22:00:00 +0300
commit4f3ed56eea905196027ec9aeec99829458ae9be6 (patch)
tree8dd6c54c8ce4abe7ae7ad23f0e943f25dac277de
parent0a1567b56c8b75fab424c859458ae31026854117 (diff)
parentd2b26a6613a679c0baf8d52e2916df132c19f291 (diff)
Merge branch 'sh-add-gl-project-name-logs' into 'master'
Add glProjectName to logs See merge request gitlab-org/gitaly!1049
-rw-r--r--changelogs/unreleased/sh-add-gl-project-name-logs.yml5
-rw-r--r--internal/helper/fieldextractors/fieldextractor.go1
-rw-r--r--internal/service/remote/list_remotes.go11
-rw-r--r--ruby/Gemfile2
-rw-r--r--ruby/Gemfile.lock4
-rw-r--r--vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/blob.pb.go2
-rw-r--r--vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/commit.pb.go268
-rw-r--r--vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/remote.pb.go180
-rw-r--r--vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/shared.pb.go88
-rw-r--r--vendor/vendor.json11
10 files changed, 336 insertions, 236 deletions
diff --git a/changelogs/unreleased/sh-add-gl-project-name-logs.yml b/changelogs/unreleased/sh-add-gl-project-name-logs.yml
new file mode 100644
index 000000000..cecbaa927
--- /dev/null
+++ b/changelogs/unreleased/sh-add-gl-project-name-logs.yml
@@ -0,0 +1,5 @@
+---
+title: Add glProjectPath to logs
+merge_request: 1049
+author:
+type: other
diff --git a/internal/helper/fieldextractors/fieldextractor.go b/internal/helper/fieldextractors/fieldextractor.go
index cb8f5aeca..aa32804e0 100644
--- a/internal/helper/fieldextractors/fieldextractor.go
+++ b/internal/helper/fieldextractors/fieldextractor.go
@@ -33,6 +33,7 @@ func formatRepoRequest(repo *gitalypb.Repository) map[string]interface{} {
"repoPath": repo.RelativePath,
"topLevelGroup": getTopLevelGroupFromRepoPath(repo.RelativePath),
"glRepository": repo.GlRepository,
+ "glProjectPath": repo.GlProjectPath,
}
}
diff --git a/internal/service/remote/list_remotes.go b/internal/service/remote/list_remotes.go
new file mode 100644
index 000000000..e57b31f34
--- /dev/null
+++ b/internal/service/remote/list_remotes.go
@@ -0,0 +1,11 @@
+package remote
+
+import (
+ "context"
+
+ "gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
+)
+
+func (s *server) ListRemotes(ctx context.Context, in *gitalypb.ListRemotesRequest) (*gitalypb.ListRemotesResponse, error) {
+ return nil, nil
+}
diff --git a/ruby/Gemfile b/ruby/Gemfile
index ac75ab493..352c5eece 100644
--- a/ruby/Gemfile
+++ b/ruby/Gemfile
@@ -6,7 +6,7 @@ gem 'bundler', '>= 1.16.5'
gem 'rugged', '~> 0.27'
gem 'github-linguist', '~> 6.1', require: 'linguist'
gem 'gitlab-markup', '~> 1.6.5'
-gem 'gitaly-proto', '~> 1.7.0'
+gem 'gitaly-proto', '~> 1.10.0'
gem 'activesupport', '~> 5.0.2'
gem 'rdoc', '~> 4.2'
gem 'gitlab-gollum-lib', '~> 4.2', require: false
diff --git a/ruby/Gemfile.lock b/ruby/Gemfile.lock
index 6cef990c7..886185c31 100644
--- a/ruby/Gemfile.lock
+++ b/ruby/Gemfile.lock
@@ -36,7 +36,7 @@ GEM
ffi (1.10.0)
gemojione (3.3.0)
json
- gitaly-proto (1.7.0)
+ gitaly-proto (1.10.0)
grpc (~> 1.0)
github-linguist (6.2.0)
charlock_holmes (~> 0.7.6)
@@ -178,7 +178,7 @@ DEPENDENCIES
bundler (>= 1.16.5)
factory_bot
faraday (~> 0.12)
- gitaly-proto (~> 1.7.0)
+ gitaly-proto (~> 1.10.0)
github-linguist (~> 6.1)
gitlab-gollum-lib (~> 4.2)
gitlab-gollum-rugged_adapter (~> 0.4.4)
diff --git a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/blob.pb.go b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/blob.pb.go
index 4e4524fa9..20085a3f8 100644
--- a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/blob.pb.go
+++ b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/blob.pb.go
@@ -206,6 +206,8 @@ It has these top-level messages:
FindRemoteRepositoryResponse
FindRemoteRootRefRequest
FindRemoteRootRefResponse
+ ListRemotesRequest
+ ListRemotesResponse
RepositoryExistsRequest
RepositoryExistsResponse
RepackIncrementalRequest
diff --git a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/commit.pb.go b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/commit.pb.go
index 3746d808d..28604ccef 100644
--- a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/commit.pb.go
+++ b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/commit.pb.go
@@ -425,13 +425,10 @@ func (m *CountCommitsResponse) GetCount() int32 {
}
type CountDivergingCommitsRequest struct {
- Repository *Repository `protobuf:"bytes,1,opt,name=repository" json:"repository,omitempty"`
- From []byte `protobuf:"bytes,2,opt,name=from,proto3" json:"from,omitempty"`
- To []byte `protobuf:"bytes,3,opt,name=to,proto3" json:"to,omitempty"`
- After *google_protobuf.Timestamp `protobuf:"bytes,4,opt,name=after" json:"after,omitempty"`
- Before *google_protobuf.Timestamp `protobuf:"bytes,5,opt,name=before" json:"before,omitempty"`
- Path []byte `protobuf:"bytes,6,opt,name=path,proto3" json:"path,omitempty"`
- MaxCount int32 `protobuf:"varint,7,opt,name=max_count,json=maxCount" json:"max_count,omitempty"`
+ Repository *Repository `protobuf:"bytes,1,opt,name=repository" json:"repository,omitempty"`
+ From []byte `protobuf:"bytes,2,opt,name=from,proto3" json:"from,omitempty"`
+ To []byte `protobuf:"bytes,3,opt,name=to,proto3" json:"to,omitempty"`
+ MaxCount int32 `protobuf:"varint,7,opt,name=max_count,json=maxCount" json:"max_count,omitempty"`
}
func (m *CountDivergingCommitsRequest) Reset() { *m = CountDivergingCommitsRequest{} }
@@ -460,27 +457,6 @@ func (m *CountDivergingCommitsRequest) GetTo() []byte {
return nil
}
-func (m *CountDivergingCommitsRequest) GetAfter() *google_protobuf.Timestamp {
- if m != nil {
- return m.After
- }
- return nil
-}
-
-func (m *CountDivergingCommitsRequest) GetBefore() *google_protobuf.Timestamp {
- if m != nil {
- return m.Before
- }
- return nil
-}
-
-func (m *CountDivergingCommitsRequest) GetPath() []byte {
- if m != nil {
- return m.Path
- }
- return nil
-}
-
func (m *CountDivergingCommitsRequest) GetMaxCount() int32 {
if m != nil {
return m.MaxCount
@@ -2659,123 +2635,123 @@ var _CommitService_serviceDesc = grpc.ServiceDesc{
func init() { proto.RegisterFile("commit.proto", fileDescriptor2) }
var fileDescriptor2 = []byte{
- // 1873 bytes of a gzipped FileDescriptorProto
+ // 1879 bytes of a gzipped FileDescriptorProto
0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xbc, 0x58, 0x5b, 0x6f, 0xdb, 0xc8,
- 0x15, 0x36, 0x75, 0xb3, 0x78, 0xe4, 0x7a, 0xe5, 0xc9, 0x4d, 0xa6, 0xed, 0xd8, 0x3b, 0xbb, 0xd9,
- 0x7a, 0xb1, 0x85, 0x12, 0xb8, 0x17, 0xb4, 0x4f, 0x85, 0xbd, 0xb1, 0x5d, 0xa7, 0x49, 0xb4, 0xa0,
- 0x05, 0x04, 0x2d, 0x0a, 0x08, 0xb4, 0x38, 0x92, 0xa6, 0xa1, 0x44, 0x2d, 0x39, 0x72, 0xac, 0x3e,
- 0xf4, 0xbd, 0x40, 0xdb, 0xf7, 0xfe, 0x88, 0x3e, 0xf4, 0x27, 0xec, 0x4b, 0x7f, 0x40, 0x7f, 0xce,
- 0xa2, 0x0f, 0x8b, 0xb9, 0x90, 0x43, 0x8a, 0xa4, 0x1d, 0xc7, 0xab, 0xbc, 0x10, 0x9c, 0x33, 0x33,
- 0xe7, 0x36, 0x73, 0xbe, 0x73, 0xce, 0xc0, 0x5a, 0xdf, 0x1f, 0x8f, 0x29, 0x6b, 0x4f, 0x03, 0x9f,
- 0xf9, 0xa8, 0x36, 0xa4, 0xcc, 0xf1, 0xe6, 0xd6, 0x5a, 0x38, 0x72, 0x02, 0xe2, 0x4a, 0xaa, 0xb5,
- 0x3b, 0xf4, 0xfd, 0xa1, 0x47, 0x9e, 0x8a, 0xd1, 0xc5, 0x6c, 0xf0, 0x94, 0xd1, 0x31, 0x09, 0x99,
- 0x33, 0x9e, 0xca, 0x05, 0xd8, 0x05, 0xf4, 0xb5, 0x60, 0x73, 0xce, 0x1c, 0x16, 0xda, 0xe4, 0xdb,
- 0x19, 0x09, 0x19, 0x3a, 0x00, 0x08, 0xc8, 0xd4, 0x0f, 0x29, 0xf3, 0x83, 0x79, 0xcb, 0xd8, 0x33,
- 0xf6, 0x1b, 0x07, 0xa8, 0x2d, 0x25, 0xb4, 0xed, 0x78, 0xc6, 0x4e, 0xac, 0x42, 0x16, 0xd4, 0x03,
- 0x72, 0x49, 0x43, 0xea, 0x4f, 0x5a, 0xa5, 0x3d, 0x63, 0x7f, 0xcd, 0x8e, 0xc7, 0xb8, 0x0f, 0xf7,
- 0x52, 0x52, 0xc2, 0xa9, 0x3f, 0x09, 0x09, 0x6a, 0x42, 0xd9, 0xa7, 0xae, 0xe0, 0x6f, 0xda, 0xfc,
- 0x17, 0x6d, 0x83, 0xe9, 0xb8, 0x2e, 0x65, 0xd4, 0x9f, 0x84, 0x82, 0x4b, 0xd5, 0xd6, 0x04, 0x3e,
- 0xeb, 0x12, 0x8f, 0xc8, 0xd9, 0xb2, 0x9c, 0x8d, 0x09, 0xf8, 0x6f, 0x06, 0x3c, 0x92, 0x52, 0xce,
- 0xc2, 0xc3, 0x49, 0x9f, 0x84, 0xcc, 0x0f, 0xee, 0x62, 0xd0, 0x2e, 0x34, 0x1c, 0xc5, 0xa6, 0x47,
- 0x5d, 0xa1, 0x8d, 0x69, 0x43, 0x44, 0x3a, 0x73, 0xd1, 0x26, 0xd4, 0xfb, 0x23, 0xea, 0xb9, 0x7c,
- 0xb6, 0x2c, 0x66, 0x57, 0xc5, 0xf8, 0xcc, 0xc5, 0xcf, 0xa0, 0x95, 0x55, 0x45, 0x59, 0x7d, 0x1f,
- 0xaa, 0x97, 0x8e, 0x37, 0x23, 0x42, 0x8d, 0xba, 0x2d, 0x07, 0xf8, 0xef, 0x06, 0x34, 0xbb, 0x01,
- 0x21, 0xc7, 0x13, 0x16, 0xcc, 0x97, 0x74, 0x0e, 0x08, 0x41, 0x65, 0xea, 0xb0, 0x91, 0xd0, 0x76,
- 0xcd, 0x16, 0xff, 0x5c, 0x1d, 0x8f, 0x8e, 0x29, 0x6b, 0x55, 0xf6, 0x8c, 0xfd, 0xb2, 0x2d, 0x07,
- 0xf8, 0x7f, 0x06, 0x6c, 0x24, 0xd4, 0x51, 0xaa, 0xff, 0x1a, 0x2a, 0x6c, 0x3e, 0x95, 0x9a, 0xaf,
- 0x1f, 0x7c, 0x1e, 0x69, 0x92, 0x59, 0xd8, 0xee, 0x5c, 0xfc, 0x99, 0xf4, 0x59, 0x77, 0x3e, 0x25,
- 0xb6, 0xd8, 0x11, 0x1d, 0x75, 0x49, 0x1f, 0x35, 0x82, 0x4a, 0x48, 0xff, 0x42, 0x84, 0x2e, 0x65,
- 0x5b, 0xfc, 0x73, 0xda, 0xd8, 0x77, 0x89, 0x50, 0xa5, 0x6a, 0x8b, 0x7f, 0x4e, 0x73, 0x1d, 0xe6,
- 0xb4, 0xaa, 0x52, 0x67, 0xfe, 0x8f, 0x7f, 0x09, 0xa0, 0x25, 0x20, 0x80, 0xda, 0xd7, 0x9d, 0x57,
- 0xaf, 0xce, 0xba, 0xcd, 0x15, 0x54, 0x87, 0xca, 0xd1, 0xcb, 0xce, 0x51, 0xd3, 0xe0, 0x7f, 0x5d,
- 0xfb, 0xf8, 0xb8, 0x59, 0x42, 0xab, 0x50, 0xee, 0x1e, 0x9e, 0x36, 0xcb, 0xd8, 0x87, 0x07, 0xf2,
- 0x54, 0xc2, 0x23, 0xc2, 0xde, 0x11, 0x32, 0xb9, 0x8b, 0x9f, 0x11, 0x54, 0x06, 0x81, 0x3f, 0x56,
- 0x3e, 0x16, 0xff, 0x68, 0x1d, 0x4a, 0xcc, 0x57, 0xde, 0x2d, 0x31, 0x1f, 0x1f, 0xc3, 0xc3, 0x45,
- 0x81, 0xca, 0x93, 0x5f, 0xc1, 0xaa, 0x0c, 0xdf, 0xb0, 0x65, 0xec, 0x95, 0xf7, 0x1b, 0x07, 0x1b,
- 0x91, 0xb8, 0x53, 0xca, 0xe4, 0x1e, 0x3b, 0x5a, 0x81, 0xff, 0x59, 0xe2, 0xf1, 0x33, 0x9b, 0xa8,
- 0x89, 0x65, 0x85, 0x29, 0x7a, 0x06, 0x55, 0x67, 0xc0, 0x48, 0x20, 0x2c, 0x68, 0x1c, 0x58, 0x6d,
- 0x89, 0x1e, 0xed, 0x08, 0x3d, 0xda, 0xdd, 0x08, 0x3d, 0x6c, 0xb9, 0x10, 0x1d, 0x40, 0xed, 0x82,
- 0x0c, 0xfc, 0x40, 0x1e, 0xd9, 0xf5, 0x5b, 0xd4, 0xca, 0xf8, 0x12, 0x56, 0x13, 0x97, 0x70, 0x0b,
- 0xcc, 0xb1, 0x73, 0xd5, 0xeb, 0x73, 0x23, 0x5b, 0x35, 0x71, 0xfa, 0xf5, 0xb1, 0x73, 0x25, 0x8c,
- 0xe6, 0x77, 0xc7, 0xf1, 0xbc, 0xd6, 0xaa, 0x08, 0x17, 0xfe, 0x8b, 0x7f, 0x06, 0xf7, 0xd3, 0xfe,
- 0xd0, 0xa1, 0x25, 0x59, 0x18, 0x82, 0x85, 0x1c, 0xe0, 0x7f, 0x94, 0x60, 0x5b, 0x2c, 0x7f, 0x4e,
- 0x2f, 0x49, 0x30, 0xa4, 0x93, 0xe1, 0x8f, 0xe0, 0xc7, 0xf7, 0x38, 0x7e, 0xed, 0xcf, 0xca, 0xed,
- 0xfd, 0x59, 0xbd, 0xb5, 0x3f, 0x6b, 0x45, 0xfe, 0x5c, 0x4d, 0xfb, 0x13, 0xf7, 0x60, 0xa7, 0xc0,
- 0x1d, 0xca, 0x8d, 0x3b, 0x00, 0x1e, 0x19, 0xb0, 0x5e, 0xd2, 0x97, 0x26, 0xa7, 0xc8, 0xf3, 0xd8,
- 0x85, 0x46, 0x40, 0x87, 0xa3, 0x68, 0x5e, 0xc2, 0x34, 0x08, 0x92, 0x14, 0xf0, 0xbd, 0x01, 0x66,
- 0x8c, 0x09, 0x39, 0x28, 0xbf, 0x09, 0xf5, 0xc0, 0xf7, 0x59, 0x4f, 0x23, 0xc2, 0x2a, 0x1f, 0x77,
- 0x24, 0x2a, 0x64, 0x10, 0xea, 0xa9, 0x42, 0x9d, 0x8a, 0x40, 0x9d, 0xad, 0x0c, 0xea, 0xb4, 0xc5,
- 0x37, 0x01, 0x36, 0x11, 0x8c, 0x54, 0x13, 0x30, 0xb2, 0x03, 0x20, 0xc3, 0x49, 0x48, 0xad, 0x09,
- 0xa9, 0xa6, 0xa4, 0x70, 0xb9, 0x5b, 0x60, 0x0e, 0x3c, 0x87, 0xf5, 0x84, 0xf0, 0x55, 0x19, 0x17,
- 0x9c, 0xf0, 0x8d, 0xc3, 0x46, 0xf8, 0x2b, 0x30, 0x63, 0x11, 0x31, 0xc2, 0xac, 0xc4, 0x08, 0x63,
- 0x24, 0x10, 0xa8, 0x8c, 0xff, 0x65, 0xc0, 0x83, 0x53, 0xc2, 0x22, 0xed, 0x28, 0x09, 0x3f, 0x26,
- 0x9a, 0x6f, 0x83, 0x19, 0x90, 0xfe, 0x2c, 0x08, 0xe9, 0xa5, 0x74, 0x58, 0xdd, 0xd6, 0x04, 0x8e,
- 0x47, 0x8b, 0xaa, 0x69, 0x3c, 0x22, 0x92, 0xb4, 0x88, 0x47, 0x1a, 0xdc, 0xa3, 0x15, 0xf8, 0x02,
- 0x9a, 0x2f, 0x69, 0xc8, 0x4e, 0xa8, 0xb7, 0x34, 0xe3, 0xf0, 0x97, 0xb0, 0x91, 0x90, 0xa1, 0xe3,
- 0x9b, 0x5b, 0x29, 0x75, 0x5c, 0xb3, 0xe5, 0x00, 0xf7, 0x61, 0xe3, 0x84, 0x4e, 0x5c, 0x85, 0x9a,
- 0x4b, 0xd2, 0xe7, 0xb7, 0x80, 0x92, 0x42, 0x94, 0x42, 0x5f, 0x42, 0x4d, 0xde, 0x21, 0x25, 0x21,
- 0x07, 0xc5, 0xd5, 0x02, 0xdc, 0x83, 0x47, 0xdc, 0xa0, 0x28, 0x1f, 0xcc, 0x3b, 0xd4, 0xbd, 0x8b,
- 0xae, 0x71, 0x42, 0x2d, 0xab, 0xa8, 0xc2, 0xa7, 0xd0, 0xca, 0x0a, 0xf8, 0x90, 0x74, 0xf3, 0xbd,
- 0x01, 0x0f, 0xb8, 0xad, 0x87, 0x9e, 0xb7, 0xe4, 0x84, 0x93, 0x82, 0xa9, 0xf2, 0x02, 0xec, 0xf3,
- 0x02, 0xe1, 0x2d, 0x9d, 0x46, 0xc5, 0x00, 0xff, 0x47, 0xbf, 0x81, 0xaa, 0x1f, 0xb8, 0x24, 0x10,
- 0xa1, 0xbd, 0x7e, 0xf0, 0x59, 0x24, 0x3b, 0x57, 0xdd, 0x76, 0x87, 0x2f, 0xb5, 0xe5, 0x0e, 0xfc,
- 0x04, 0xaa, 0x62, 0xcc, 0xc3, 0xf6, 0x75, 0xe7, 0xf5, 0xb1, 0x0a, 0xe0, 0xce, 0x37, 0x1d, 0x59,
- 0x2c, 0x3c, 0x3f, 0xec, 0x1e, 0x37, 0x4b, 0x3c, 0x44, 0x16, 0x99, 0x7d, 0x88, 0x0f, 0xff, 0x5f,
- 0x4a, 0xde, 0x97, 0xa5, 0x39, 0x30, 0x2e, 0xde, 0xa4, 0xf3, 0xe4, 0x00, 0x3d, 0x84, 0x9a, 0x3f,
- 0x18, 0x84, 0x84, 0x29, 0xdf, 0xa9, 0x91, 0x0e, 0x9f, 0x6a, 0x22, 0x7c, 0xf8, 0xea, 0x81, 0xef,
- 0x79, 0xfe, 0x3b, 0x81, 0x8a, 0x75, 0x5b, 0x8d, 0x38, 0xcc, 0x73, 0x9f, 0xf7, 0xc6, 0x24, 0x18,
- 0x92, 0x50, 0xa5, 0x5f, 0xe0, 0xa4, 0x57, 0x82, 0x82, 0x3e, 0x85, 0x35, 0x97, 0x86, 0xce, 0x85,
- 0x47, 0x7a, 0xef, 0x1c, 0xef, 0x6d, 0xab, 0x2e, 0x56, 0x34, 0x14, 0xed, 0x8d, 0xe3, 0xbd, 0xd5,
- 0x19, 0xd0, 0xbc, 0x7d, 0x06, 0x84, 0xf7, 0xce, 0x80, 0xaa, 0x40, 0x68, 0xe8, 0x02, 0xe1, 0x08,
- 0xee, 0xa5, 0xbc, 0xff, 0x21, 0x47, 0x38, 0x8a, 0x8a, 0xb7, 0x97, 0xce, 0x64, 0x38, 0x73, 0x86,
- 0xcb, 0xc3, 0xba, 0x7f, 0xc7, 0x9d, 0x4b, 0x42, 0x94, 0x52, 0xf9, 0x04, 0x4c, 0x2f, 0x22, 0x2a,
- 0xa5, 0xf7, 0x23, 0x51, 0x05, 0x7b, 0xda, 0x11, 0xc5, 0xd6, 0x5b, 0xad, 0x17, 0x50, 0x8f, 0xc8,
- 0x3c, 0xb2, 0x26, 0xce, 0x98, 0xa8, 0x94, 0x2c, 0xfe, 0xf9, 0xdd, 0x10, 0x9d, 0xa3, 0x50, 0xae,
- 0x64, 0xcb, 0x81, 0x2c, 0xa8, 0x3c, 0x3f, 0x50, 0xfd, 0x8d, 0x1c, 0xe0, 0x19, 0x7c, 0x62, 0x3b,
- 0xef, 0x8e, 0x3c, 0x67, 0x4c, 0x3e, 0x62, 0x6e, 0xc3, 0x5f, 0x40, 0x53, 0x8b, 0x55, 0xee, 0x89,
- 0xba, 0x03, 0x23, 0xd1, 0x1d, 0xfc, 0x15, 0x5a, 0x2f, 0x9d, 0x08, 0x08, 0x4f, 0xfc, 0x80, 0xe7,
- 0xf0, 0x8f, 0xa9, 0xe7, 0x09, 0x6c, 0xe6, 0xc8, 0xbf, 0x7d, 0xc6, 0xf8, 0x8f, 0x01, 0x3b, 0x1c,
- 0xd1, 0x35, 0xb3, 0xf0, 0xc4, 0x0f, 0x78, 0x3e, 0xfe, 0x31, 0xad, 0x31, 0x6f, 0xd3, 0x1f, 0xe6,
- 0x40, 0x4c, 0x35, 0x09, 0x31, 0xf8, 0xbf, 0x06, 0x3c, 0x2e, 0xd2, 0x59, 0x79, 0xe0, 0xf5, 0x62,
- 0x10, 0xfe, 0x22, 0xd2, 0xf8, 0xfa, 0x8d, 0xed, 0xd8, 0xa1, 0x82, 0x1a, 0x31, 0xb1, 0xba, 0xf0,
- 0x93, 0xd4, 0x4c, 0xc2, 0xc5, 0xa5, 0x1b, 0x5c, 0x9c, 0x32, 0xd8, 0x94, 0x06, 0xbf, 0xa8, 0xd4,
- 0x8d, 0x66, 0x09, 0x7f, 0x17, 0xc7, 0x64, 0x78, 0x34, 0x7f, 0x45, 0xc2, 0x90, 0xc7, 0xd3, 0x92,
- 0x2e, 0x91, 0x76, 0x66, 0x79, 0x11, 0xaf, 0x73, 0x5c, 0x9f, 0xd7, 0x3f, 0xdd, 0x87, 0xea, 0xb7,
- 0x33, 0x12, 0xcc, 0x55, 0x61, 0x2b, 0x07, 0xbc, 0x22, 0xc8, 0x9a, 0xf0, 0x21, 0x50, 0x48, 0x61,
- 0xf7, 0x84, 0x7a, 0x8c, 0x04, 0xe7, 0x23, 0x27, 0x7c, 0x43, 0xd9, 0xe8, 0x9c, 0x0e, 0x27, 0x0e,
- 0x9b, 0x05, 0xe4, 0xae, 0x3d, 0x54, 0x38, 0x72, 0x42, 0x51, 0xc4, 0xac, 0xd9, 0xe2, 0x1f, 0xff,
- 0x0a, 0xf6, 0x8a, 0x45, 0xe9, 0xa0, 0x17, 0xfb, 0x8c, 0xc4, 0xbe, 0x29, 0xec, 0x1c, 0x5f, 0xb1,
- 0xc0, 0xe9, 0x2b, 0xe5, 0xe3, 0x6d, 0x77, 0x51, 0x70, 0x0b, 0x54, 0x8b, 0xa0, 0x1f, 0x80, 0xea,
- 0x92, 0x70, 0xe6, 0xe2, 0x1e, 0x3c, 0x2e, 0x92, 0xa8, 0xf4, 0xdc, 0x06, 0x33, 0x8c, 0x88, 0x0a,
- 0xa1, 0x34, 0x41, 0xe4, 0x57, 0x3a, 0x9c, 0x10, 0xb7, 0xc7, 0xc8, 0x15, 0x53, 0x97, 0x02, 0x24,
- 0xa9, 0x4b, 0xae, 0x18, 0xf6, 0xc1, 0x3a, 0x25, 0x8b, 0xcc, 0xef, 0xe4, 0x70, 0xdd, 0x04, 0x51,
- 0x37, 0x54, 0xb5, 0xa3, 0x19, 0x19, 0x14, 0xe2, 0x39, 0x6c, 0xe5, 0x0a, 0x54, 0xe6, 0xa4, 0xbc,
- 0x61, 0xa4, 0xbd, 0x91, 0xb6, 0xb5, 0x74, 0x83, 0xad, 0xe5, 0x8c, 0xad, 0x63, 0x68, 0xc5, 0xa2,
- 0xd5, 0x55, 0x5d, 0xa6, 0xa5, 0x36, 0x6c, 0xe6, 0x88, 0x7b, 0x1f, 0x3b, 0x5b, 0xb0, 0x3a, 0x96,
- 0x1b, 0x94, 0x95, 0xd1, 0xf0, 0xe0, 0xbb, 0xf5, 0x08, 0x88, 0xce, 0x49, 0x70, 0x49, 0xfb, 0x04,
- 0xbd, 0x81, 0xe6, 0xe2, 0x2b, 0x20, 0xda, 0x4d, 0x27, 0xef, 0xcc, 0x53, 0xa5, 0xb5, 0x57, 0xbc,
- 0x40, 0xea, 0x87, 0x57, 0xd0, 0xf3, 0x64, 0x7f, 0xdd, 0xca, 0x79, 0x86, 0x93, 0xac, 0x36, 0x0b,
- 0x1f, 0xe8, 0xf0, 0xca, 0x33, 0x03, 0x9d, 0xc3, 0x7a, 0xfa, 0x75, 0x0a, 0xed, 0xa4, 0x65, 0x2f,
- 0x3c, 0x93, 0x59, 0x8f, 0x8b, 0xa6, 0x13, 0x4c, 0x7f, 0x0f, 0x6b, 0xc9, 0xa7, 0x19, 0xb4, 0xa5,
- 0xf7, 0x64, 0x1e, 0xb0, 0xac, 0xed, 0xfc, 0xc9, 0xd8, 0xce, 0x01, 0x3c, 0xc8, 0x7d, 0xa9, 0x40,
- 0x9f, 0xa7, 0x36, 0x16, 0xbc, 0xeb, 0x58, 0x4f, 0x6e, 0x58, 0x15, 0xcb, 0x39, 0x87, 0xf5, 0x74,
- 0x5f, 0xac, 0x3d, 0x91, 0xdb, 0xca, 0x6b, 0x4f, 0xe4, 0xb7, 0xd3, 0xc2, 0x13, 0xcf, 0xc1, 0x8c,
- 0x3b, 0x58, 0x7d, 0x48, 0x8b, 0x8d, 0xb3, 0x3e, 0xa4, 0x4c, 0xbb, 0x2b, 0xb8, 0x1c, 0x03, 0xe8,
- 0x4a, 0x16, 0x6d, 0x26, 0x1b, 0x9e, 0x54, 0xc3, 0x6b, 0x59, 0x79, 0x53, 0xb1, 0x85, 0xbf, 0x83,
- 0x46, 0xe2, 0x05, 0x1e, 0x59, 0xe9, 0x93, 0x4c, 0x3e, 0xfe, 0x5b, 0x5b, 0xb9, 0x73, 0x49, 0x5f,
- 0xa5, 0x1b, 0x24, 0xed, 0xab, 0xdc, 0x2e, 0x4c, 0xfb, 0x2a, 0xbf, 0xaf, 0x12, 0x56, 0xbe, 0x80,
- 0x46, 0xa2, 0x5e, 0x47, 0x39, 0xb6, 0x64, 0xd5, 0xcb, 0x29, 0xf0, 0x05, 0xaf, 0x2e, 0x7c, 0xb2,
- 0x50, 0x18, 0xa3, 0xc7, 0x85, 0x15, 0xb3, 0xe4, 0xb9, 0x7b, 0x43, 0x45, 0x8d, 0x57, 0xd0, 0x21,
- 0xd4, 0xa3, 0xe2, 0x13, 0x3d, 0x8a, 0xc1, 0x27, 0x5d, 0x05, 0x5b, 0xad, 0xec, 0x44, 0x42, 0xb1,
- 0x3f, 0xc2, 0x46, 0xa6, 0x2e, 0x44, 0x71, 0xb8, 0x17, 0x95, 0xac, 0xd6, 0xa7, 0xd7, 0xac, 0x88,
- 0xd5, 0x7b, 0x0b, 0x0f, 0xf3, 0xab, 0x27, 0xf4, 0xe4, 0xa6, 0xea, 0x4a, 0x4a, 0xf9, 0xe2, 0xfd,
- 0x8a, 0x30, 0x61, 0xc8, 0x1f, 0x22, 0x5c, 0xd3, 0x75, 0xc5, 0x22, 0xae, 0x65, 0x8a, 0xa6, 0x45,
- 0x5c, 0xcb, 0x96, 0x24, 0x11, 0xeb, 0xc5, 0x47, 0x0c, 0xcd, 0xba, 0xe0, 0xfd, 0x44, 0xb3, 0x2e,
- 0x7a, 0xff, 0x10, 0xac, 0x43, 0x68, 0x15, 0x55, 0x16, 0xe8, 0xa7, 0xfa, 0x52, 0x5d, 0x5b, 0xe6,
- 0x58, 0xfb, 0x37, 0x2f, 0x8c, 0x44, 0xee, 0x1b, 0xcf, 0x0c, 0x7e, 0x2e, 0xf9, 0x45, 0x82, 0x3e,
- 0x97, 0x6b, 0xcb, 0x16, 0x7d, 0x2e, 0xd7, 0xd7, 0x1a, 0xc2, 0xc2, 0x0b, 0xb8, 0x97, 0x93, 0xbf,
- 0x11, 0x4e, 0x80, 0x55, 0x41, 0x35, 0x61, 0x7d, 0x76, 0xed, 0x9a, 0x84, 0x8c, 0x3f, 0xc1, 0x46,
- 0x26, 0x73, 0xea, 0x4b, 0x5c, 0x94, 0xc3, 0xf5, 0x25, 0x2e, 0x4c, 0xbb, 0x9c, 0xfb, 0x45, 0x4d,
- 0x74, 0xf9, 0x3f, 0xff, 0x21, 0x00, 0x00, 0xff, 0xff, 0x0f, 0xb4, 0x30, 0x05, 0xdc, 0x1c, 0x00,
- 0x00,
+ 0x15, 0x36, 0x75, 0xe7, 0x91, 0xeb, 0x95, 0x27, 0x37, 0x99, 0xb6, 0x63, 0xef, 0xec, 0x66, 0xeb,
+ 0xc5, 0x16, 0x4a, 0xe0, 0x5e, 0xd0, 0x3e, 0x15, 0xf6, 0x46, 0x76, 0xed, 0x26, 0xd1, 0x82, 0x16,
+ 0x10, 0xb4, 0x28, 0x20, 0xd0, 0xe2, 0x48, 0x9a, 0x86, 0x12, 0xb5, 0xe4, 0xc8, 0xb1, 0xfa, 0xd0,
+ 0xf7, 0x02, 0x45, 0xdf, 0xfb, 0x03, 0xfa, 0xd8, 0x87, 0xfe, 0x84, 0x7d, 0xe9, 0x0f, 0xe8, 0xcf,
+ 0x59, 0xf4, 0x61, 0x31, 0x17, 0x72, 0x48, 0x89, 0xb4, 0x93, 0x78, 0x95, 0x17, 0x82, 0x73, 0x66,
+ 0xe6, 0xdc, 0x66, 0xce, 0x77, 0xce, 0x19, 0x58, 0xef, 0xfb, 0xe3, 0x31, 0x65, 0xad, 0x69, 0xe0,
+ 0x33, 0x1f, 0x55, 0x86, 0x94, 0x39, 0xde, 0xdc, 0x5a, 0x0f, 0x47, 0x4e, 0x40, 0x5c, 0x49, 0xb5,
+ 0xf6, 0x86, 0xbe, 0x3f, 0xf4, 0xc8, 0x53, 0x31, 0xba, 0x9c, 0x0d, 0x9e, 0x32, 0x3a, 0x26, 0x21,
+ 0x73, 0xc6, 0x53, 0xb9, 0x00, 0xbb, 0x80, 0xbe, 0x16, 0x6c, 0x2e, 0x98, 0xc3, 0x42, 0x9b, 0x7c,
+ 0x3b, 0x23, 0x21, 0x43, 0x87, 0x00, 0x01, 0x99, 0xfa, 0x21, 0x65, 0x7e, 0x30, 0x6f, 0x1a, 0xfb,
+ 0xc6, 0x41, 0xfd, 0x10, 0xb5, 0xa4, 0x84, 0x96, 0x1d, 0xcf, 0xd8, 0x89, 0x55, 0xc8, 0x82, 0x5a,
+ 0x40, 0xae, 0x68, 0x48, 0xfd, 0x49, 0xb3, 0xb0, 0x6f, 0x1c, 0xac, 0xdb, 0xf1, 0x18, 0xf7, 0xe1,
+ 0x5e, 0x4a, 0x4a, 0x38, 0xf5, 0x27, 0x21, 0x41, 0x0d, 0x28, 0xfa, 0xd4, 0x15, 0xfc, 0x4d, 0x9b,
+ 0xff, 0xa2, 0x1d, 0x30, 0x1d, 0xd7, 0xa5, 0x8c, 0xfa, 0x93, 0x50, 0x70, 0x29, 0xdb, 0x9a, 0xc0,
+ 0x67, 0x5d, 0xe2, 0x11, 0x39, 0x5b, 0x94, 0xb3, 0x31, 0x01, 0xff, 0xcd, 0x80, 0x47, 0x52, 0xca,
+ 0x59, 0x78, 0x34, 0xe9, 0x93, 0x90, 0xf9, 0xc1, 0x5d, 0x0c, 0xda, 0x83, 0xba, 0xa3, 0xd8, 0xf4,
+ 0xa8, 0x2b, 0xb4, 0x31, 0x6d, 0x88, 0x48, 0x67, 0x2e, 0xda, 0x82, 0x5a, 0x7f, 0x44, 0x3d, 0x97,
+ 0xcf, 0x16, 0xc5, 0x6c, 0x55, 0x8c, 0xcf, 0x5c, 0xfc, 0x0c, 0x9a, 0xcb, 0xaa, 0x28, 0xab, 0xef,
+ 0x43, 0xf9, 0xca, 0xf1, 0x66, 0x44, 0xa8, 0x51, 0xb3, 0xe5, 0x00, 0xff, 0xdd, 0x80, 0x46, 0x37,
+ 0x20, 0xa4, 0x3d, 0x61, 0xc1, 0x7c, 0x45, 0xe7, 0x80, 0x10, 0x94, 0xa6, 0x0e, 0x1b, 0x09, 0x6d,
+ 0xd7, 0x6d, 0xf1, 0xcf, 0xd5, 0xf1, 0xe8, 0x98, 0xb2, 0x66, 0x69, 0xdf, 0x38, 0x28, 0xda, 0x72,
+ 0x80, 0xff, 0x67, 0xc0, 0x66, 0x42, 0x1d, 0xa5, 0xfa, 0xaf, 0xa1, 0xc4, 0xe6, 0x53, 0xa9, 0xf9,
+ 0xc6, 0xe1, 0xe7, 0x91, 0x26, 0x4b, 0x0b, 0x5b, 0x9d, 0xcb, 0x3f, 0x93, 0x3e, 0xeb, 0xce, 0xa7,
+ 0xc4, 0x16, 0x3b, 0xa2, 0xa3, 0x2e, 0xe8, 0xa3, 0x46, 0x50, 0x0a, 0xe9, 0x5f, 0x88, 0xd0, 0xa5,
+ 0x68, 0x8b, 0x7f, 0x4e, 0x1b, 0xfb, 0x2e, 0x11, 0xaa, 0x94, 0x6d, 0xf1, 0xcf, 0x69, 0xae, 0xc3,
+ 0x9c, 0x66, 0x59, 0xea, 0xcc, 0xff, 0xf1, 0x2f, 0x01, 0xb4, 0x04, 0x04, 0x50, 0xf9, 0xba, 0xf3,
+ 0xf2, 0xe5, 0x59, 0xb7, 0xb1, 0x86, 0x6a, 0x50, 0x3a, 0x7e, 0xd1, 0x39, 0x6e, 0x18, 0xfc, 0xaf,
+ 0x6b, 0xb7, 0xdb, 0x8d, 0x02, 0xaa, 0x42, 0xb1, 0x7b, 0x74, 0xda, 0x28, 0x62, 0x1f, 0x1e, 0xc8,
+ 0x53, 0x09, 0x8f, 0x09, 0x7b, 0x4b, 0xc8, 0xe4, 0x2e, 0x7e, 0x46, 0x50, 0x1a, 0x04, 0xfe, 0x58,
+ 0xf9, 0x58, 0xfc, 0xa3, 0x0d, 0x28, 0x30, 0x5f, 0x79, 0xb7, 0xc0, 0x7c, 0xdc, 0x86, 0x87, 0x8b,
+ 0x02, 0x95, 0x27, 0xbf, 0x82, 0xaa, 0x0c, 0xdf, 0xb0, 0x69, 0xec, 0x17, 0x0f, 0xea, 0x87, 0x9b,
+ 0x91, 0xb8, 0x53, 0xca, 0xe4, 0x1e, 0x3b, 0x5a, 0x81, 0xff, 0x51, 0xe0, 0xf1, 0x33, 0x9b, 0xa8,
+ 0x89, 0x55, 0x85, 0x29, 0x7a, 0x06, 0x65, 0x67, 0xc0, 0x48, 0x20, 0x2c, 0xa8, 0x1f, 0x5a, 0x2d,
+ 0x89, 0x1e, 0xad, 0x08, 0x3d, 0x5a, 0xdd, 0x08, 0x3d, 0x6c, 0xb9, 0x10, 0x1d, 0x42, 0xe5, 0x92,
+ 0x0c, 0xfc, 0x40, 0x1e, 0xd9, 0xcd, 0x5b, 0xd4, 0xca, 0xf8, 0x12, 0x96, 0x13, 0x97, 0x70, 0x1b,
+ 0xcc, 0xb1, 0x73, 0xdd, 0xeb, 0x73, 0x23, 0x9b, 0x15, 0x71, 0xfa, 0xb5, 0xb1, 0x73, 0x2d, 0x8c,
+ 0xe6, 0x77, 0xc7, 0xf1, 0xbc, 0x66, 0x55, 0x84, 0x0b, 0xff, 0xc5, 0x3f, 0x83, 0xfb, 0x69, 0x7f,
+ 0xe8, 0xd0, 0x92, 0x2c, 0x0c, 0xc1, 0x42, 0x0e, 0xf0, 0xbf, 0x0c, 0xd8, 0x11, 0xcb, 0x9f, 0xd3,
+ 0x2b, 0x12, 0x0c, 0xe9, 0x64, 0xf8, 0x23, 0xf8, 0xf1, 0x1d, 0x8e, 0x3f, 0x6d, 0x55, 0x35, 0x6d,
+ 0xd5, 0x79, 0xa9, 0x56, 0x6a, 0x94, 0xcf, 0x4b, 0xb5, 0x72, 0xa3, 0x72, 0x5e, 0xaa, 0x55, 0x1a,
+ 0x55, 0xdc, 0x83, 0xdd, 0x1c, 0x35, 0x95, 0x79, 0xbb, 0x00, 0x1e, 0x19, 0xb0, 0x5e, 0xd2, 0x46,
+ 0x93, 0x53, 0xa4, 0x9f, 0xf6, 0xa0, 0x1e, 0xd0, 0xe1, 0x28, 0x9a, 0x97, 0xf0, 0x09, 0x82, 0x24,
+ 0x16, 0xe0, 0xef, 0x0d, 0x30, 0xe3, 0x58, 0xcd, 0x40, 0xdf, 0x2d, 0xa8, 0x05, 0xbe, 0xcf, 0x7a,
+ 0x3a, 0x52, 0xab, 0x7c, 0xdc, 0x91, 0xd1, 0xba, 0x84, 0x1c, 0x4f, 0x15, 0x1a, 0x94, 0x04, 0x1a,
+ 0x6c, 0x2f, 0xa1, 0x41, 0x4b, 0x7c, 0x13, 0x20, 0x10, 0x85, 0x77, 0x39, 0x11, 0xde, 0xbb, 0x00,
+ 0xf2, 0x9a, 0x0b, 0xa9, 0x15, 0x21, 0xd5, 0x94, 0x14, 0x2e, 0x77, 0x1b, 0xcc, 0x81, 0xe7, 0xb0,
+ 0x9e, 0x10, 0x5e, 0x95, 0xf7, 0x95, 0x13, 0xbe, 0x71, 0xd8, 0x08, 0x7f, 0x05, 0x66, 0x2c, 0x22,
+ 0x8e, 0xfc, 0xb5, 0x38, 0xf2, 0x8d, 0x04, 0x32, 0x14, 0xf1, 0x3f, 0x0d, 0x78, 0x70, 0x4a, 0x58,
+ 0xa4, 0x1d, 0x25, 0xe1, 0xc7, 0x44, 0xd9, 0x1d, 0x30, 0x03, 0xd2, 0x9f, 0x05, 0x21, 0xbd, 0x92,
+ 0x0e, 0xab, 0xd9, 0x9a, 0xc0, 0x71, 0x62, 0x51, 0x35, 0x8d, 0x13, 0x44, 0x92, 0x16, 0x71, 0x42,
+ 0x83, 0x6e, 0xb4, 0x02, 0x5f, 0x42, 0xe3, 0x05, 0x0d, 0xd9, 0x09, 0xf5, 0x56, 0x66, 0x1c, 0xfe,
+ 0x12, 0x36, 0x13, 0x32, 0x74, 0xdc, 0x71, 0x2b, 0xa5, 0x8e, 0xeb, 0xb6, 0x1c, 0xe0, 0x3e, 0x6c,
+ 0x9e, 0xd0, 0x89, 0xab, 0xd0, 0x6c, 0x45, 0xfa, 0xfc, 0x16, 0x50, 0x52, 0x88, 0x52, 0xe8, 0x4b,
+ 0xa8, 0xc8, 0x3b, 0xa4, 0x24, 0x64, 0xa0, 0xab, 0x5a, 0x80, 0x7b, 0xf0, 0x88, 0x1b, 0x14, 0xe1,
+ 0xf4, 0xbc, 0x43, 0xdd, 0xbb, 0xe8, 0x1a, 0x27, 0xba, 0xa2, 0x8a, 0x2a, 0x7c, 0x0a, 0xcd, 0x65,
+ 0x01, 0x1f, 0x92, 0x06, 0xbe, 0x37, 0xe0, 0x01, 0xb7, 0xf5, 0xc8, 0xf3, 0x56, 0x9c, 0x08, 0x52,
+ 0xc0, 0x55, 0x5c, 0x80, 0x63, 0x9e, 0xb8, 0xdf, 0xd0, 0x69, 0x94, 0xa4, 0xf9, 0x3f, 0xfa, 0x0d,
+ 0x94, 0xfd, 0xc0, 0x25, 0x81, 0x08, 0xed, 0x8d, 0xc3, 0xcf, 0x22, 0xd9, 0x99, 0xea, 0xb6, 0x3a,
+ 0x7c, 0xa9, 0x2d, 0x77, 0xe0, 0x27, 0x50, 0x16, 0x63, 0x1e, 0xb6, 0xaf, 0x3a, 0xaf, 0xda, 0x2a,
+ 0x80, 0x3b, 0xdf, 0x74, 0x64, 0x12, 0x7f, 0x7e, 0xd4, 0x6d, 0x37, 0x0a, 0x3c, 0x44, 0x16, 0x99,
+ 0x7d, 0x88, 0x0f, 0xff, 0x5f, 0x48, 0xde, 0x97, 0x95, 0x39, 0x30, 0x2e, 0xaa, 0xa4, 0xf3, 0xe4,
+ 0x00, 0x3d, 0x84, 0x8a, 0x3f, 0x18, 0x84, 0x84, 0x29, 0xdf, 0xa9, 0x91, 0x0e, 0x9f, 0x72, 0x22,
+ 0x7c, 0xf8, 0xea, 0x81, 0xef, 0x79, 0xfe, 0x5b, 0x81, 0x8a, 0x35, 0x5b, 0x8d, 0x38, 0xcc, 0x73,
+ 0x9f, 0xf7, 0xc6, 0x24, 0x18, 0x92, 0x50, 0xa5, 0x45, 0xe0, 0xa4, 0x97, 0x82, 0x82, 0x3e, 0x85,
+ 0x75, 0x97, 0x86, 0xce, 0xa5, 0x47, 0x7a, 0x6f, 0x1d, 0xef, 0x4d, 0xb3, 0x26, 0x56, 0xd4, 0x15,
+ 0xed, 0xb5, 0xe3, 0xbd, 0xd1, 0x99, 0xde, 0x7c, 0xff, 0x4c, 0x0f, 0xef, 0x9c, 0xe9, 0x55, 0xe2,
+ 0xae, 0xeb, 0xc4, 0x7d, 0x0c, 0xf7, 0x52, 0xde, 0xff, 0x90, 0x23, 0x1c, 0x45, 0x45, 0xd5, 0x0b,
+ 0x67, 0x32, 0x9c, 0x39, 0xc3, 0xd5, 0x61, 0xdd, 0xbf, 0xe3, 0x8e, 0x22, 0x21, 0x4a, 0xa9, 0x7c,
+ 0x02, 0xa6, 0x17, 0x11, 0x95, 0xd2, 0x07, 0x91, 0xa8, 0x9c, 0x3d, 0xad, 0x88, 0x62, 0xeb, 0xad,
+ 0xd6, 0x39, 0xd4, 0x22, 0x32, 0x8f, 0xac, 0x89, 0x33, 0x26, 0x2a, 0x25, 0x8b, 0x7f, 0x7e, 0x37,
+ 0x44, 0x47, 0x27, 0x94, 0x2b, 0xd8, 0x72, 0x20, 0x0b, 0x1d, 0xcf, 0x0f, 0x54, 0xdf, 0x21, 0x07,
+ 0x78, 0x06, 0x9f, 0xd8, 0xce, 0xdb, 0x63, 0xcf, 0x19, 0x93, 0x8f, 0x98, 0xdb, 0xf0, 0x17, 0xd0,
+ 0xd0, 0x62, 0x95, 0x7b, 0xa2, 0xaa, 0xdd, 0x48, 0x54, 0xed, 0x7f, 0x85, 0xe6, 0x0b, 0x27, 0x02,
+ 0xc2, 0x13, 0x3f, 0xe0, 0x39, 0xfc, 0x63, 0xea, 0x79, 0x02, 0x5b, 0x19, 0xf2, 0xdf, 0x3f, 0x63,
+ 0xfc, 0xc7, 0x80, 0x5d, 0x8e, 0xe8, 0x9a, 0x59, 0x78, 0xe2, 0x07, 0x3c, 0x1f, 0xff, 0x98, 0xd6,
+ 0x98, 0xef, 0xd3, 0xb7, 0x65, 0x40, 0x4c, 0x39, 0x09, 0x31, 0xf8, 0xbf, 0x06, 0x3c, 0xce, 0xd3,
+ 0x59, 0x79, 0xe0, 0xd5, 0x62, 0x10, 0xfe, 0x22, 0xd2, 0xf8, 0xe6, 0x8d, 0xad, 0xd8, 0xa1, 0x82,
+ 0x1a, 0x31, 0xb1, 0xba, 0xf0, 0x93, 0xd4, 0x4c, 0xc2, 0xc5, 0x85, 0x5b, 0x5c, 0x9c, 0x32, 0xd8,
+ 0x94, 0x06, 0x9f, 0x97, 0x6a, 0x46, 0xa3, 0x80, 0xbf, 0x8b, 0x63, 0x32, 0x3c, 0x9e, 0xbf, 0x24,
+ 0x61, 0xc8, 0xe3, 0x69, 0x45, 0x97, 0x48, 0x3b, 0xb3, 0xb8, 0x88, 0xd7, 0x19, 0xae, 0xcf, 0xea,
+ 0x6b, 0xee, 0x43, 0xf9, 0xdb, 0x19, 0x09, 0xe6, 0xaa, 0xb0, 0x95, 0x03, 0x5e, 0x11, 0x2c, 0x9b,
+ 0xf0, 0x21, 0x50, 0x48, 0x61, 0xef, 0x84, 0x7a, 0x8c, 0x04, 0x17, 0x23, 0x27, 0x7c, 0x4d, 0xd9,
+ 0xe8, 0x82, 0x0e, 0x27, 0x0e, 0x9b, 0x05, 0xe4, 0xae, 0xbd, 0x4d, 0x38, 0x72, 0x42, 0x51, 0xc4,
+ 0xac, 0xdb, 0xe2, 0x1f, 0xff, 0x0a, 0xf6, 0xf3, 0x45, 0xe9, 0xa0, 0x17, 0xfb, 0x8c, 0xc4, 0xbe,
+ 0x29, 0xec, 0xb6, 0xaf, 0x59, 0xe0, 0xf4, 0x95, 0xf2, 0xf1, 0xb6, 0xbb, 0x28, 0xb8, 0x0d, 0xaa,
+ 0x45, 0xd0, 0x0f, 0x33, 0x35, 0x49, 0x38, 0x73, 0x71, 0x0f, 0x1e, 0xe7, 0x49, 0x54, 0x7a, 0xee,
+ 0x80, 0x19, 0x46, 0x44, 0x85, 0x50, 0x9a, 0x20, 0xf2, 0x2b, 0x1d, 0x4e, 0x88, 0xdb, 0x63, 0xe4,
+ 0x9a, 0xa9, 0x4b, 0x01, 0x92, 0xd4, 0x25, 0xd7, 0x0c, 0xfb, 0x60, 0x9d, 0x92, 0x45, 0xe6, 0x77,
+ 0x72, 0xb8, 0x6e, 0x82, 0xa8, 0x1b, 0xaa, 0xda, 0xd1, 0x8c, 0x0c, 0x0a, 0xf1, 0x1c, 0xb6, 0x33,
+ 0x05, 0x2a, 0x73, 0x52, 0xde, 0x30, 0xd2, 0xde, 0x48, 0xdb, 0x5a, 0xb8, 0xc5, 0xd6, 0xe2, 0x92,
+ 0xad, 0x63, 0x68, 0xc6, 0xa2, 0xd5, 0x55, 0x5d, 0xa5, 0xa5, 0x36, 0x6c, 0x65, 0x88, 0x7b, 0x17,
+ 0x3b, 0x9b, 0x50, 0x1d, 0xcb, 0x0d, 0xca, 0xca, 0x68, 0x78, 0xf8, 0xdd, 0x46, 0x04, 0x44, 0x17,
+ 0x24, 0xb8, 0xa2, 0x7d, 0x82, 0x5e, 0x43, 0x63, 0xf1, 0x75, 0x0e, 0xed, 0xa5, 0x93, 0xf7, 0xd2,
+ 0x13, 0xa2, 0xb5, 0x9f, 0xbf, 0x40, 0xea, 0x87, 0xd7, 0xd0, 0xf3, 0x64, 0x7f, 0xdd, 0xcc, 0x78,
+ 0x1e, 0x93, 0xac, 0xb6, 0x72, 0x1f, 0xce, 0xf0, 0xda, 0x33, 0x03, 0x5d, 0xc0, 0x46, 0xfa, 0xd5,
+ 0x08, 0xed, 0xa6, 0x65, 0x2f, 0x3c, 0x5f, 0x59, 0x8f, 0xf3, 0xa6, 0x13, 0x4c, 0x7f, 0x0f, 0xeb,
+ 0xc9, 0x27, 0x13, 0xb4, 0xad, 0xf7, 0x2c, 0x3d, 0x2c, 0x59, 0x3b, 0xd9, 0x93, 0xb1, 0x9d, 0x03,
+ 0x78, 0x90, 0xf9, 0x52, 0x81, 0x3e, 0x4f, 0x6d, 0xcc, 0x79, 0x6f, 0xb1, 0x9e, 0xdc, 0xb2, 0x2a,
+ 0x96, 0x73, 0x01, 0x1b, 0xe9, 0xbe, 0x58, 0x7b, 0x22, 0xb3, 0x95, 0xd7, 0x9e, 0xc8, 0x6e, 0xa7,
+ 0x85, 0x27, 0x9e, 0x83, 0x19, 0x77, 0xb0, 0xfa, 0x90, 0x16, 0x1b, 0x67, 0x7d, 0x48, 0x4b, 0xed,
+ 0xae, 0xe0, 0xd2, 0x06, 0xd0, 0x95, 0x2c, 0xda, 0x4a, 0x36, 0x3c, 0xa9, 0x86, 0xd7, 0xb2, 0xb2,
+ 0xa6, 0x62, 0x0b, 0x7f, 0x07, 0xf5, 0xc4, 0xcb, 0x38, 0xb2, 0xd2, 0x27, 0x99, 0x7c, 0x94, 0xb7,
+ 0xb6, 0x33, 0xe7, 0x92, 0xbe, 0x4a, 0x37, 0x48, 0xda, 0x57, 0x99, 0x5d, 0x98, 0xf6, 0x55, 0x76,
+ 0x5f, 0x25, 0xac, 0x3c, 0x87, 0x7a, 0xa2, 0x5e, 0x47, 0x19, 0xb6, 0x2c, 0xab, 0x97, 0x51, 0xe0,
+ 0x0b, 0x5e, 0x5d, 0xf8, 0x64, 0xa1, 0x30, 0x46, 0x8f, 0x73, 0x2b, 0x66, 0xc9, 0x73, 0xef, 0x96,
+ 0x8a, 0x1a, 0xaf, 0xa1, 0x23, 0xa8, 0x45, 0xc5, 0x27, 0x7a, 0x14, 0x83, 0x4f, 0xba, 0x0a, 0xb6,
+ 0x9a, 0xcb, 0x13, 0x09, 0xc5, 0xfe, 0x08, 0x9b, 0x4b, 0x75, 0x21, 0x8a, 0xc3, 0x3d, 0xaf, 0x64,
+ 0xb5, 0x3e, 0xbd, 0x61, 0x45, 0xac, 0xde, 0x1b, 0x78, 0x98, 0x5d, 0x3d, 0xa1, 0x27, 0xb7, 0x55,
+ 0x57, 0x52, 0xca, 0x17, 0xef, 0x56, 0x84, 0x09, 0x43, 0xfe, 0x10, 0xe1, 0x9a, 0xae, 0x2b, 0x16,
+ 0x71, 0x6d, 0xa9, 0x68, 0x5a, 0xc4, 0xb5, 0xe5, 0x92, 0x24, 0x62, 0xbd, 0xf8, 0x88, 0xa1, 0x59,
+ 0xe7, 0xbc, 0x9f, 0x68, 0xd6, 0x79, 0xef, 0x1f, 0x82, 0x75, 0x08, 0xcd, 0xbc, 0xca, 0x02, 0xfd,
+ 0x54, 0x5f, 0xaa, 0x1b, 0xcb, 0x1c, 0xeb, 0xe0, 0xf6, 0x85, 0x91, 0xc8, 0x03, 0xe3, 0x99, 0xc1,
+ 0xcf, 0x25, 0xbb, 0x48, 0xd0, 0xe7, 0x72, 0x63, 0xd9, 0xa2, 0xcf, 0xe5, 0xe6, 0x5a, 0x43, 0x58,
+ 0x78, 0x09, 0xf7, 0x32, 0xf2, 0x37, 0xc2, 0x09, 0xb0, 0xca, 0xa9, 0x26, 0xac, 0xcf, 0x6e, 0x5c,
+ 0x93, 0x90, 0xf1, 0x27, 0xd8, 0x5c, 0xca, 0x9c, 0xfa, 0x12, 0xe7, 0xe5, 0x70, 0x7d, 0x89, 0x73,
+ 0xd3, 0x2e, 0xe7, 0x7e, 0x59, 0x11, 0x5d, 0xfe, 0xcf, 0x7f, 0x08, 0x00, 0x00, 0xff, 0xff, 0xd7,
+ 0x68, 0x06, 0x91, 0x74, 0x1c, 0x00, 0x00,
}
diff --git a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/remote.pb.go b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/remote.pb.go
index 13ee1f309..2cba9a2f7 100644
--- a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/remote.pb.go
+++ b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/remote.pb.go
@@ -276,6 +276,70 @@ func (m *FindRemoteRootRefResponse) GetRef() string {
return ""
}
+type ListRemotesRequest struct {
+ Repository *Repository `protobuf:"bytes,1,opt,name=repository" json:"repository,omitempty"`
+}
+
+func (m *ListRemotesRequest) Reset() { *m = ListRemotesRequest{} }
+func (m *ListRemotesRequest) String() string { return proto.CompactTextString(m) }
+func (*ListRemotesRequest) ProtoMessage() {}
+func (*ListRemotesRequest) Descriptor() ([]byte, []int) { return fileDescriptor10, []int{12} }
+
+func (m *ListRemotesRequest) GetRepository() *Repository {
+ if m != nil {
+ return m.Repository
+ }
+ return nil
+}
+
+type ListRemotesResponse struct {
+ Remotes []*ListRemotesResponse_Remote `protobuf:"bytes,1,rep,name=remotes" json:"remotes,omitempty"`
+}
+
+func (m *ListRemotesResponse) Reset() { *m = ListRemotesResponse{} }
+func (m *ListRemotesResponse) String() string { return proto.CompactTextString(m) }
+func (*ListRemotesResponse) ProtoMessage() {}
+func (*ListRemotesResponse) Descriptor() ([]byte, []int) { return fileDescriptor10, []int{13} }
+
+func (m *ListRemotesResponse) GetRemotes() []*ListRemotesResponse_Remote {
+ if m != nil {
+ return m.Remotes
+ }
+ return nil
+}
+
+type ListRemotesResponse_Remote struct {
+ Name string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
+ FetchUrl string `protobuf:"bytes,2,opt,name=fetch_url,json=fetchUrl" json:"fetch_url,omitempty"`
+ PushUrl string `protobuf:"bytes,3,opt,name=push_url,json=pushUrl" json:"push_url,omitempty"`
+}
+
+func (m *ListRemotesResponse_Remote) Reset() { *m = ListRemotesResponse_Remote{} }
+func (m *ListRemotesResponse_Remote) String() string { return proto.CompactTextString(m) }
+func (*ListRemotesResponse_Remote) ProtoMessage() {}
+func (*ListRemotesResponse_Remote) Descriptor() ([]byte, []int) { return fileDescriptor10, []int{13, 0} }
+
+func (m *ListRemotesResponse_Remote) GetName() string {
+ if m != nil {
+ return m.Name
+ }
+ return ""
+}
+
+func (m *ListRemotesResponse_Remote) GetFetchUrl() string {
+ if m != nil {
+ return m.FetchUrl
+ }
+ return ""
+}
+
+func (m *ListRemotesResponse_Remote) GetPushUrl() string {
+ if m != nil {
+ return m.PushUrl
+ }
+ return ""
+}
+
func init() {
proto.RegisterType((*AddRemoteRequest)(nil), "gitaly.AddRemoteRequest")
proto.RegisterType((*AddRemoteResponse)(nil), "gitaly.AddRemoteResponse")
@@ -289,6 +353,9 @@ func init() {
proto.RegisterType((*FindRemoteRepositoryResponse)(nil), "gitaly.FindRemoteRepositoryResponse")
proto.RegisterType((*FindRemoteRootRefRequest)(nil), "gitaly.FindRemoteRootRefRequest")
proto.RegisterType((*FindRemoteRootRefResponse)(nil), "gitaly.FindRemoteRootRefResponse")
+ proto.RegisterType((*ListRemotesRequest)(nil), "gitaly.ListRemotesRequest")
+ proto.RegisterType((*ListRemotesResponse)(nil), "gitaly.ListRemotesResponse")
+ proto.RegisterType((*ListRemotesResponse_Remote)(nil), "gitaly.ListRemotesResponse.Remote")
}
// Reference imports to suppress errors if they are not otherwise used.
@@ -308,6 +375,7 @@ type RemoteServiceClient interface {
UpdateRemoteMirror(ctx context.Context, opts ...grpc.CallOption) (RemoteService_UpdateRemoteMirrorClient, error)
FindRemoteRepository(ctx context.Context, in *FindRemoteRepositoryRequest, opts ...grpc.CallOption) (*FindRemoteRepositoryResponse, error)
FindRemoteRootRef(ctx context.Context, in *FindRemoteRootRefRequest, opts ...grpc.CallOption) (*FindRemoteRootRefResponse, error)
+ ListRemotes(ctx context.Context, in *ListRemotesRequest, opts ...grpc.CallOption) (*ListRemotesResponse, error)
}
type remoteServiceClient struct {
@@ -397,6 +465,15 @@ func (c *remoteServiceClient) FindRemoteRootRef(ctx context.Context, in *FindRem
return out, nil
}
+func (c *remoteServiceClient) ListRemotes(ctx context.Context, in *ListRemotesRequest, opts ...grpc.CallOption) (*ListRemotesResponse, error) {
+ out := new(ListRemotesResponse)
+ err := grpc.Invoke(ctx, "/gitaly.RemoteService/ListRemotes", in, out, c.cc, opts...)
+ if err != nil {
+ return nil, err
+ }
+ return out, nil
+}
+
// Server API for RemoteService service
type RemoteServiceServer interface {
@@ -406,6 +483,7 @@ type RemoteServiceServer interface {
UpdateRemoteMirror(RemoteService_UpdateRemoteMirrorServer) error
FindRemoteRepository(context.Context, *FindRemoteRepositoryRequest) (*FindRemoteRepositoryResponse, error)
FindRemoteRootRef(context.Context, *FindRemoteRootRefRequest) (*FindRemoteRootRefResponse, error)
+ ListRemotes(context.Context, *ListRemotesRequest) (*ListRemotesResponse, error)
}
func RegisterRemoteServiceServer(s *grpc.Server, srv RemoteServiceServer) {
@@ -528,6 +606,24 @@ func _RemoteService_FindRemoteRootRef_Handler(srv interface{}, ctx context.Conte
return interceptor(ctx, in, info, handler)
}
+func _RemoteService_ListRemotes_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
+ in := new(ListRemotesRequest)
+ if err := dec(in); err != nil {
+ return nil, err
+ }
+ if interceptor == nil {
+ return srv.(RemoteServiceServer).ListRemotes(ctx, in)
+ }
+ info := &grpc.UnaryServerInfo{
+ Server: srv,
+ FullMethod: "/gitaly.RemoteService/ListRemotes",
+ }
+ handler := func(ctx context.Context, req interface{}) (interface{}, error) {
+ return srv.(RemoteServiceServer).ListRemotes(ctx, req.(*ListRemotesRequest))
+ }
+ return interceptor(ctx, in, info, handler)
+}
+
var _RemoteService_serviceDesc = grpc.ServiceDesc{
ServiceName: "gitaly.RemoteService",
HandlerType: (*RemoteServiceServer)(nil),
@@ -552,6 +648,10 @@ var _RemoteService_serviceDesc = grpc.ServiceDesc{
MethodName: "FindRemoteRootRef",
Handler: _RemoteService_FindRemoteRootRef_Handler,
},
+ {
+ MethodName: "ListRemotes",
+ Handler: _RemoteService_ListRemotes_Handler,
+ },
},
Streams: []grpc.StreamDesc{
{
@@ -566,41 +666,47 @@ var _RemoteService_serviceDesc = grpc.ServiceDesc{
func init() { proto.RegisterFile("remote.proto", fileDescriptor10) }
var fileDescriptor10 = []byte{
- // 574 bytes of a gzipped FileDescriptorProto
- 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xb4, 0x55, 0x4d, 0x6f, 0xd3, 0x30,
- 0x18, 0x26, 0x4b, 0xd7, 0xb5, 0xef, 0x3a, 0xd4, 0xba, 0xd5, 0x48, 0xb3, 0x4a, 0x74, 0x06, 0xa4,
- 0x5e, 0xe8, 0xa1, 0x7c, 0x5c, 0x11, 0x3b, 0x20, 0x60, 0x1a, 0x07, 0x23, 0x2e, 0x48, 0x28, 0x64,
- 0xed, 0x9b, 0x25, 0x5a, 0x1b, 0x17, 0xdb, 0x1d, 0xf4, 0x67, 0xf0, 0x1f, 0x38, 0xf0, 0x9b, 0xf8,
- 0x35, 0xc8, 0x89, 0x93, 0xa6, 0x34, 0x2d, 0x12, 0x13, 0x37, 0xfb, 0x79, 0x3f, 0xfc, 0x3e, 0x8f,
- 0x1f, 0x27, 0xd0, 0x10, 0x38, 0xe3, 0x0a, 0x87, 0x73, 0xc1, 0x15, 0x27, 0xd5, 0xab, 0x48, 0xf9,
- 0xd3, 0xa5, 0xdb, 0x90, 0xa1, 0x2f, 0x70, 0x92, 0xa2, 0xf4, 0xa7, 0x05, 0xcd, 0x97, 0x93, 0x09,
- 0x4b, 0x32, 0x19, 0x7e, 0x59, 0xa0, 0x54, 0x64, 0x04, 0x20, 0x70, 0xce, 0x65, 0xa4, 0xb8, 0x58,
- 0x3a, 0x56, 0xdf, 0x1a, 0x1c, 0x8e, 0xc8, 0x30, 0xad, 0x1f, 0xb2, 0x3c, 0xc2, 0x0a, 0x59, 0x84,
- 0x40, 0x25, 0xf6, 0x67, 0xe8, 0xec, 0xf5, 0xad, 0x41, 0x9d, 0x25, 0x6b, 0xd2, 0x04, 0x7b, 0x21,
- 0xa6, 0x8e, 0x9d, 0x40, 0x7a, 0x49, 0x1e, 0xc1, 0xdd, 0x59, 0x24, 0x04, 0x17, 0x9e, 0xc0, 0x60,
- 0xe6, 0xcf, 0xa5, 0xb3, 0xdf, 0xb7, 0x07, 0x75, 0x76, 0x94, 0xa2, 0x2c, 0x05, 0xdf, 0x56, 0x6a,
- 0x95, 0xe6, 0x7e, 0x06, 0x9a, 0x54, 0xda, 0x86, 0x56, 0x61, 0x52, 0x39, 0xe7, 0xb1, 0x44, 0xfa,
- 0x09, 0xda, 0x1a, 0xb9, 0xc1, 0xff, 0xc2, 0x80, 0x0e, 0xa1, 0xb3, 0xde, 0x3e, 0x3d, 0x96, 0x1c,
- 0x43, 0x55, 0xa0, 0x5c, 0x4c, 0x55, 0xd2, 0xbb, 0xc6, 0xcc, 0x8e, 0x7e, 0xb7, 0xc0, 0x7d, 0x85,
- 0x6a, 0x1c, 0xbe, 0x89, 0x15, 0x8a, 0xd8, 0x9f, 0xde, 0x7e, 0xac, 0x17, 0xd0, 0x4a, 0xef, 0xd1,
- 0x2b, 0x94, 0xee, 0x6d, 0x2d, 0x6d, 0x0a, 0x73, 0x62, 0x86, 0xd0, 0x67, 0x70, 0x52, 0x3a, 0xd2,
- 0x5f, 0xa8, 0xfc, 0xb2, 0xa0, 0xfb, 0x61, 0x3e, 0xf1, 0x95, 0xe1, 0x7e, 0x61, 0x6e, 0xe8, 0xdf,
- 0x99, 0x74, 0xa1, 0x26, 0x30, 0xf0, 0x0a, 0x22, 0x1f, 0x08, 0x0c, 0xde, 0x69, 0xa7, 0x3c, 0x85,
- 0x63, 0x1e, 0x4f, 0x97, 0xde, 0xa5, 0xf0, 0xe3, 0x71, 0x88, 0xd2, 0x9b, 0xf9, 0x6a, 0x1c, 0x46,
- 0xf1, 0x95, 0x63, 0xf7, 0xed, 0x41, 0x83, 0x75, 0x74, 0xf4, 0xcc, 0x04, 0x2f, 0x4c, 0x8c, 0xdc,
- 0x83, 0x03, 0x29, 0x43, 0xef, 0x1a, 0x97, 0x4e, 0x25, 0xe9, 0x57, 0x95, 0x32, 0x3c, 0xc7, 0x25,
- 0xb9, 0x0f, 0x87, 0xd7, 0x31, 0xff, 0x1a, 0x7b, 0x21, 0x97, 0x4a, 0x7b, 0x4c, 0x07, 0x21, 0x81,
- 0x5e, 0x6b, 0x84, 0xf6, 0xc0, 0x2d, 0xe3, 0x66, 0x4c, 0xa5, 0x15, 0x8b, 0xe2, 0xdc, 0x6a, 0x39,
- 0x19, 0xc3, 0x3d, 0x51, 0x4c, 0x87, 0x12, 0xde, 0x75, 0x66, 0x76, 0xf4, 0x39, 0xf4, 0xca, 0xcb,
- 0x56, 0x4a, 0xe3, 0xb7, 0x48, 0x0f, 0x64, 0x94, 0x4e, 0x77, 0x34, 0x00, 0xa7, 0x50, 0xc7, 0xb9,
- 0x62, 0x18, 0xdc, 0x46, 0xe7, 0xd5, 0x7c, 0x7b, 0x6b, 0xf3, 0x3d, 0x86, 0x6e, 0xc9, 0x39, 0x66,
- 0xb8, 0x26, 0xd8, 0x02, 0x03, 0xc3, 0x48, 0x2f, 0x47, 0x3f, 0x2a, 0x70, 0x94, 0xe6, 0xbe, 0x47,
- 0x71, 0x13, 0x8d, 0x91, 0x9c, 0x41, 0x3d, 0x7f, 0x81, 0xc4, 0xc9, 0xa6, 0xf8, 0xf3, 0xf3, 0xe1,
- 0x76, 0x4b, 0x22, 0x46, 0xd9, 0x3b, 0xe4, 0x33, 0xb4, 0x4b, 0xdc, 0x48, 0x68, 0x56, 0xb3, 0xfd,
- 0xf5, 0xb8, 0x0f, 0x76, 0xe6, 0xe4, 0x27, 0x9c, 0x43, 0xa3, 0xf8, 0x66, 0xc9, 0xc9, 0x4a, 0xae,
- 0x8d, 0x0f, 0x85, 0xdb, 0x2b, 0x0f, 0xe6, 0xcd, 0x3c, 0x20, 0x9b, 0x46, 0x21, 0xa7, 0x59, 0xd5,
- 0xd6, 0x07, 0xe2, 0xd2, 0x5d, 0x29, 0x59, 0xfb, 0x81, 0x45, 0xc6, 0xd0, 0x29, 0x33, 0x0d, 0x59,
- 0x91, 0xdd, 0xee, 0x44, 0xf7, 0xe1, 0xee, 0xa4, 0x9c, 0xc5, 0x47, 0x68, 0x6d, 0xdc, 0x3c, 0xe9,
- 0x97, 0x14, 0xaf, 0x99, 0xcf, 0x3d, 0xdd, 0x91, 0x91, 0xf5, 0xbe, 0xac, 0x26, 0x3f, 0x92, 0x27,
- 0xbf, 0x03, 0x00, 0x00, 0xff, 0xff, 0x29, 0x20, 0x7c, 0x92, 0x6e, 0x06, 0x00, 0x00,
+ // 670 bytes of a gzipped FileDescriptorProto
+ 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xb4, 0x55, 0xcb, 0x6e, 0xd3, 0x4c,
+ 0x14, 0xae, 0xeb, 0x34, 0x97, 0x93, 0xf4, 0x57, 0x3a, 0xa9, 0xfa, 0x3b, 0x4e, 0x25, 0xd2, 0x01,
+ 0x24, 0x6f, 0xc8, 0x22, 0x5c, 0x56, 0x48, 0x88, 0x2e, 0x50, 0xa1, 0x94, 0x85, 0xa1, 0x1b, 0x24,
+ 0x64, 0xdc, 0x64, 0x5c, 0x5b, 0x75, 0x3c, 0x66, 0x66, 0x52, 0xc8, 0x63, 0xf0, 0x16, 0xf0, 0x4a,
+ 0x3c, 0x04, 0xcf, 0x80, 0xc6, 0x33, 0x76, 0x1c, 0xea, 0x04, 0x89, 0x8a, 0x9d, 0xe7, 0xdc, 0xe6,
+ 0xfb, 0xce, 0x7c, 0xe7, 0x18, 0x3a, 0x8c, 0xcc, 0xa8, 0x20, 0xa3, 0x94, 0x51, 0x41, 0x51, 0xfd,
+ 0x32, 0x12, 0x7e, 0xbc, 0xb0, 0x3b, 0x3c, 0xf4, 0x19, 0x99, 0x2a, 0x2b, 0xfe, 0x66, 0x40, 0xf7,
+ 0xf9, 0x74, 0xea, 0x66, 0x91, 0x2e, 0xf9, 0x34, 0x27, 0x5c, 0xa0, 0x31, 0x00, 0x23, 0x29, 0xe5,
+ 0x91, 0xa0, 0x6c, 0x61, 0x19, 0x43, 0xc3, 0x69, 0x8f, 0xd1, 0x48, 0xe5, 0x8f, 0xdc, 0xc2, 0xe3,
+ 0x96, 0xa2, 0x10, 0x82, 0x5a, 0xe2, 0xcf, 0x88, 0xb5, 0x3d, 0x34, 0x9c, 0x96, 0x9b, 0x7d, 0xa3,
+ 0x2e, 0x98, 0x73, 0x16, 0x5b, 0x66, 0x66, 0x92, 0x9f, 0xe8, 0x3e, 0xfc, 0x37, 0x8b, 0x18, 0xa3,
+ 0xcc, 0x63, 0x24, 0x98, 0xf9, 0x29, 0xb7, 0x76, 0x86, 0xa6, 0xd3, 0x72, 0x77, 0x95, 0xd5, 0x55,
+ 0xc6, 0x57, 0xb5, 0x66, 0xad, 0xbb, 0x93, 0x1b, 0x75, 0x28, 0xee, 0xc1, 0x5e, 0x09, 0x29, 0x4f,
+ 0x69, 0xc2, 0x09, 0xfe, 0x00, 0x3d, 0x69, 0xb9, 0x26, 0xff, 0x84, 0x01, 0x1e, 0xc1, 0xfe, 0x6a,
+ 0x79, 0x75, 0x2d, 0x3a, 0x80, 0x3a, 0x23, 0x7c, 0x1e, 0x8b, 0xac, 0x76, 0xd3, 0xd5, 0x27, 0xfc,
+ 0xd5, 0x00, 0xfb, 0x05, 0x11, 0x93, 0xf0, 0x65, 0x22, 0x08, 0x4b, 0xfc, 0xf8, 0xf6, 0xb0, 0x9e,
+ 0xc1, 0x9e, 0x7a, 0x47, 0xaf, 0x94, 0xba, 0xbd, 0x36, 0xb5, 0xcb, 0xf4, 0x8d, 0xb9, 0x05, 0x3f,
+ 0x86, 0x41, 0x25, 0xa4, 0x3f, 0x50, 0xf9, 0x61, 0x40, 0xff, 0x3c, 0x9d, 0xfa, 0x42, 0x73, 0x3f,
+ 0xd3, 0x2f, 0xf4, 0xf7, 0x4c, 0xfa, 0xd0, 0x64, 0x24, 0xf0, 0x4a, 0x4d, 0x6e, 0x30, 0x12, 0xbc,
+ 0x91, 0x4a, 0x79, 0x04, 0x07, 0x34, 0x89, 0x17, 0xde, 0x05, 0xf3, 0x93, 0x49, 0x48, 0xb8, 0x37,
+ 0xf3, 0xc5, 0x24, 0x8c, 0x92, 0x4b, 0xcb, 0x1c, 0x9a, 0x4e, 0xc7, 0xdd, 0x97, 0xde, 0x63, 0xed,
+ 0x3c, 0xd3, 0x3e, 0xf4, 0x3f, 0x34, 0x38, 0x0f, 0xbd, 0x2b, 0xb2, 0xb0, 0x6a, 0x59, 0xbd, 0x3a,
+ 0xe7, 0xe1, 0x29, 0x59, 0xa0, 0x3b, 0xd0, 0xbe, 0x4a, 0xe8, 0xe7, 0xc4, 0x0b, 0x29, 0x17, 0x52,
+ 0x63, 0xd2, 0x09, 0x99, 0xe9, 0x44, 0x5a, 0xf0, 0x21, 0xd8, 0x55, 0xdc, 0xb4, 0xa8, 0x64, 0xc7,
+ 0xa2, 0xa4, 0x90, 0x5a, 0x41, 0x46, 0x73, 0xcf, 0x3a, 0x26, 0x5d, 0x19, 0xef, 0x96, 0xab, 0x4f,
+ 0xf8, 0x09, 0x1c, 0x56, 0xa7, 0x2d, 0x3b, 0x4d, 0xbe, 0x44, 0x12, 0x90, 0xee, 0xb4, 0x3a, 0xe1,
+ 0x00, 0xac, 0x52, 0x1e, 0xa5, 0xc2, 0x25, 0xc1, 0x6d, 0xfa, 0xbc, 0xc4, 0xb7, 0xbd, 0x82, 0xef,
+ 0x01, 0xf4, 0x2b, 0xee, 0xd1, 0xe0, 0xba, 0x60, 0x32, 0x12, 0x68, 0x46, 0xf2, 0x13, 0x9f, 0x00,
+ 0x7a, 0x1d, 0x71, 0xa1, 0xc2, 0xf9, 0x2d, 0x00, 0xe1, 0xef, 0x06, 0xf4, 0x56, 0x4a, 0xe9, 0x3b,
+ 0x9f, 0x42, 0x43, 0x41, 0x93, 0x1d, 0x31, 0x9d, 0xf6, 0x18, 0xe7, 0x85, 0x2a, 0xa2, 0x47, 0x1a,
+ 0x77, 0x9e, 0x62, 0xbf, 0x83, 0xba, 0x32, 0x15, 0x93, 0x6b, 0x94, 0x76, 0xcf, 0x00, 0x5a, 0x81,
+ 0x54, 0xbd, 0x27, 0x37, 0x90, 0xea, 0x43, 0x33, 0x33, 0x9c, 0xb3, 0x58, 0x2a, 0x31, 0x9d, 0x73,
+ 0xe5, 0x53, 0xdb, 0xa9, 0x21, 0xcf, 0xe7, 0x2c, 0x1e, 0xff, 0xac, 0xc1, 0xae, 0x2a, 0xfb, 0x96,
+ 0xb0, 0xeb, 0x68, 0x42, 0xd0, 0x31, 0xb4, 0x8a, 0xbd, 0x83, 0xac, 0x1c, 0xe1, 0xef, 0x4b, 0xd3,
+ 0xee, 0x57, 0x78, 0xb4, 0x9e, 0xb6, 0xd0, 0x47, 0xe8, 0x55, 0xcc, 0x20, 0x2a, 0xf8, 0xae, 0xdf,
+ 0x19, 0xf6, 0xdd, 0x8d, 0x31, 0xc5, 0x0d, 0xa7, 0xd0, 0x29, 0x6f, 0x2a, 0x34, 0x58, 0xbe, 0xc9,
+ 0x8d, 0xf5, 0x68, 0x1f, 0x56, 0x3b, 0x8b, 0x62, 0x1e, 0xa0, 0x9b, 0xe3, 0x81, 0x8e, 0xf2, 0xac,
+ 0xb5, 0x6b, 0xc1, 0xc6, 0x9b, 0x42, 0xf2, 0xf2, 0x8e, 0x81, 0x26, 0xb0, 0x5f, 0x35, 0x2a, 0x68,
+ 0x49, 0x76, 0xfd, 0xfc, 0xd9, 0xf7, 0x36, 0x07, 0x15, 0x2c, 0xde, 0xc3, 0xde, 0x0d, 0xbd, 0xa3,
+ 0x61, 0x45, 0xf2, 0xca, 0xc8, 0xd9, 0x47, 0x1b, 0x22, 0x8a, 0xda, 0x27, 0xd0, 0x2e, 0x69, 0x14,
+ 0xd9, 0x95, 0xc2, 0x55, 0xf5, 0x06, 0x1b, 0x44, 0x8d, 0xb7, 0x2e, 0xea, 0xd9, 0x8f, 0xf8, 0xe1,
+ 0xaf, 0x00, 0x00, 0x00, 0xff, 0xff, 0x18, 0x61, 0x50, 0x1b, 0xae, 0x07, 0x00, 0x00,
}
diff --git a/vendor/vendor.json b/vendor/vendor.json
index a765305a8..c380fbe79 100644
--- a/vendor/vendor.json
+++ b/vendor/vendor.json
@@ -495,14 +495,13 @@
"revisionTime": "2018-11-02T16:30:54Z"
},
{
- "checksumSHA1": "v//yPIdKqUgtH5edzbGS/smwVkI=",
+ "checksumSHA1": "PCaYb2TVXfvhTQZqc5+uOIU8jHU=",
"path": "gitlab.com/gitlab-org/gitaly-proto/go/gitalypb",
- "revision": "3cdbf69a754a59e56578d935a8848de27bba08a6",
- "revisionTime": "2019-01-04T19:41:27Z",
- "version": "v1.8.0",
- "versionExact": "v1.8.0"
+ "revision": "c181aa5999ae0d27ca143dce93b6d9ed44da06b1",
+ "revisionTime": "2019-01-24T10:20:43Z",
+ "version": "v1.10.0",
+ "versionExact": "v1.10.0"
},
-
{
"checksumSHA1": "R6fNN36q3UydLODupK0vdx9h/CY=",
"path": "gitlab.com/gitlab-org/labkit/correlation",
diff --git a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/shared.pb.go b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/shared.pb.go
index c141236a1..f28c13c41 100644
--- a/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/shared.pb.go
+++ b/vendor/gitlab.com/gitlab-org/gitaly-proto/go/gitalypb/shared.pb.go
@@ -26,12 +26,12 @@ type Repository struct {
// associated with. May be left empty on RPC's that do not perform callbacks.
// During project creation, `gl_repository` may not be known.
GlRepository string `protobuf:"bytes,6,opt,name=gl_repository,json=glRepository" json:"gl_repository,omitempty"`
// The human-readable GitLab project name (e.g. gitlab-org/gitlab-ce).
// When hashed storage is use, this associates a project name with its
// path on disk. The name can change over time (e.g. when a project is
// renamed). This is primarily used for logging/debugging at the
// moment.
- GlProjectName string `protobuf:"bytes,7,opt,name=gl_project_name,json=glProjectName" json:"gl_project_name,omitempty"`
+ GlProjectPath string `protobuf:"bytes,8,opt,name=gl_project_path,json=glProjectPath" json:"gl_project_path,omitempty"`
}
func (m *Repository) Reset() { *m = Repository{} }
@@ -74,9 +74,9 @@ func (m *Repository) GetGlRepository() string {
return ""
}
-func (m *Repository) GetGlProjectName() string {
+func (m *Repository) GetGlProjectPath() string {
if m != nil {
- return m.GlProjectName
+ return m.GlProjectPath
}
return ""
}
@@ -334,43 +334,43 @@ func init() {
func init() { proto.RegisterFile("shared.proto", fileDescriptor13) }
var fileDescriptor13 = []byte{
- // 594 bytes of a gzipped FileDescriptorProto
- 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x53, 0xc1, 0x6e, 0xd4, 0x3c,
- 0x10, 0xd6, 0x66, 0xb3, 0xdb, 0xee, 0x6c, 0xfa, 0xff, 0x60, 0x7a, 0x88, 0x8a, 0xaa, 0x96, 0x20,
- 0xa1, 0x1e, 0x50, 0x8a, 0x16, 0x89, 0x7b, 0x0b, 0xa8, 0x2a, 0x07, 0xa8, 0xd2, 0xf6, 0xc2, 0x25,
- 0xf2, 0x6e, 0xa6, 0x5e, 0x23, 0x67, 0x1d, 0xd9, 0x93, 0x8a, 0xf6, 0x89, 0x78, 0x18, 0xde, 0x83,
- 0xd7, 0x40, 0xb6, 0x93, 0xa5, 0x40, 0x41, 0xdc, 0x3c, 0x9f, 0x3f, 0xcf, 0xcc, 0x37, 0xdf, 0x18,
- 0x12, 0xbb, 0xe4, 0x06, 0xab, 0xbc, 0x31, 0x9a, 0x34, 0x1b, 0x0b, 0x49, 0x5c, 0xdd, 0xec, 0xec,
- 0x09, 0xad, 0x85, 0xc2, 0x43, 0x8f, 0xce, 0xdb, 0xab, 0x43, 0x92, 0x35, 0x5a, 0xe2, 0x75, 0x13,
- 0x88, 0xd9, 0x97, 0x08, 0xa0, 0xc0, 0x46, 0x5b, 0x49, 0xda, 0xdc, 0xb0, 0x27, 0x90, 0x58, 0xd2,
- 0x86, 0x0b, 0x2c, 0x57, 0xbc, 0xc6, 0x34, 0xda, 0x1f, 0x1c, 0x4c, 0x8a, 0x69, 0x87, 0xbd, 0xe7,
- 0x35, 0xb2, 0xa7, 0xb0, 0x65, 0x50, 0x71, 0x92, 0xd7, 0x58, 0x36, 0x9c, 0x96, 0xe9, 0xd0, 0x73,
- 0x92, 0x1e, 0x3c, 0xe3, 0xb4, 0x64, 0x2f, 0x60, 0x5b, 0x48, 0x2a, 0xf5, 0xfc, 0x13, 0x2e, 0xa8,
- 0xac, 0xa4, 0xc1, 0x85, 0xcb, 0x9f, 0xc6, 0x9e, 0xcb, 0x84, 0xa4, 0x0f, 0xfe, 0xea, 0x4d, 0x7f,
- 0xc3, 0x4e, 0x60, 0xdf, 0xbd, 0xe0, 0x8a, 0xd0, 0xac, 0x38, 0xe1, 0xaf, 0x6f, 0x25, 0xda, 0x74,
- 0xb4, 0x3f, 0x3c, 0x98, 0x14, 0xbb, 0x42, 0xd2, 0x51, 0x4f, 0xfb, 0x39, 0x8d, 0x44, 0xeb, 0xfa,
- 0x13, 0xaa, 0x34, 0x6b, 0x4d, 0xe9, 0x38, 0xf4, 0x27, 0xd4, 0x1d, 0x9d, 0xcf, 0xe0, 0x7f, 0xa1,
- 0xca, 0xc6, 0x68, 0x5f, 0xc3, 0x4b, 0xdd, 0xf0, 0xb4, 0x2d, 0xa1, 0xce, 0x02, 0xea, 0xc4, 0xbe,
- 0x8b, 0x37, 0x07, 0x0f, 0xa2, 0x22, 0x76, 0x3a, 0xb3, 0x6f, 0x03, 0x98, 0x9c, 0x48, 0x7a, 0xad,
- 0xeb, 0x5a, 0x12, 0xfb, 0x0f, 0x22, 0x59, 0xa5, 0x03, 0xff, 0x28, 0x92, 0x15, 0x4b, 0x61, 0xc3,
- 0xb6, 0xbe, 0x19, 0x3f, 0xb4, 0xa4, 0xe8, 0x43, 0xc6, 0x20, 0x9e, 0xeb, 0xea, 0xc6, 0xcf, 0x29,
- 0x29, 0xfc, 0x99, 0x3d, 0x87, 0x31, 0x6f, 0x69, 0xa9, 0x8d, 0x9f, 0xc8, 0x74, 0xb6, 0x9d, 0x07,
- 0xc3, 0xf2, 0x90, 0xfd, 0xc8, 0xdf, 0x15, 0x1d, 0x87, 0xcd, 0x60, 0xb2, 0xf0, 0x38, 0xa1, 0x49,
- 0x47, 0x7f, 0x79, 0xf0, 0x83, 0xc6, 0x76, 0x01, 0x1a, 0x6e, 0x70, 0x45, 0xa5, 0xac, 0x6c, 0x3a,
- 0xf6, 0x93, 0x9b, 0x04, 0xe4, 0xb4, 0xb2, 0xec, 0x31, 0x4c, 0x5c, 0x23, 0xa5, 0x95, 0xb7, 0x41,
- 0xfa, 0xb0, 0xd8, 0x74, 0xc0, 0xb9, 0xbc, 0xc5, 0x6c, 0x09, 0xc9, 0xdd, 0xb4, 0x4e, 0x81, 0x1f,
- 0xd1, 0x20, 0x28, 0x70, 0x67, 0xb6, 0x0d, 0x23, 0xac, 0xb9, 0x54, 0x9d, 0xda, 0x10, 0xb0, 0x1c,
- 0xe2, 0x8a, 0x13, 0x7a, 0xad, 0xd3, 0xd9, 0x4e, 0x1e, 0xd6, 0x2f, 0xef, 0xd7, 0x2f, 0xbf, 0xe8,
- 0xd7, 0xaf, 0xf0, 0xbc, 0x2c, 0x03, 0x78, 0xfb, 0x59, 0xd2, 0x39, 0x71, 0x6a, 0xad, 0xcb, 0x79,
- 0xcd, 0x55, 0x1b, 0x0a, 0x8d, 0x8a, 0x10, 0x64, 0x17, 0x30, 0x3e, 0x36, 0x7c, 0xb5, 0x58, 0xde,
- 0xdb, 0xc7, 0x2b, 0xd8, 0x22, 0x6e, 0x04, 0x52, 0x19, 0xb4, 0xfb, 0x7e, 0xa6, 0xb3, 0x87, 0xfd,
- 0x7c, 0xd6, 0x8e, 0x15, 0x49, 0xe0, 0x85, 0x28, 0xfb, 0x3a, 0x80, 0xe1, 0x05, 0x17, 0xf7, 0xe6,
- 0x0c, 0xde, 0x46, 0x6b, 0x6f, 0x7f, 0xab, 0x31, 0xfc, 0xa7, 0x1a, 0x6e, 0x27, 0x6a, 0xb4, 0x96,
- 0x0b, 0xf4, 0x36, 0x27, 0x45, 0x1f, 0xba, 0x7f, 0xd6, 0x1d, 0x83, 0x03, 0x23, 0xef, 0xc0, 0xb4,
- 0xc3, 0x9c, 0x09, 0x6e, 0x45, 0x88, 0x0b, 0x81, 0xc6, 0x2f, 0xf0, 0x1f, 0x57, 0x24, 0x70, 0xb2,
- 0x2b, 0x88, 0x2f, 0x2d, 0x1a, 0xf6, 0x08, 0x46, 0x42, 0x95, 0xeb, 0xcd, 0x8c, 0x85, 0x3a, 0xad,
- 0xd6, 0x1a, 0xa3, 0xfb, 0xfc, 0x1b, 0xde, 0xf5, 0x6f, 0x0f, 0xa6, 0x42, 0x95, 0xad, 0x75, 0x9f,
- 0xab, 0xc6, 0xee, 0xbb, 0x82, 0x50, 0x97, 0x1d, 0x72, 0x0c, 0x1f, 0x37, 0x43, 0x1b, 0xcd, 0x7c,
- 0x3e, 0xf6, 0xb6, 0xbe, 0xfc, 0x1e, 0x00, 0x00, 0xff, 0xff, 0xce, 0x46, 0x02, 0xaa, 0x7b, 0x04,
- 0x00, 0x00,
+ // 603 bytes of a gzipped FileDescriptorProto
+ 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x53, 0x51, 0x6f, 0xd3, 0x3c,
+ 0x14, 0x55, 0xd2, 0xb4, 0x6b, 0x6f, 0xb3, 0xef, 0x1b, 0x66, 0x0f, 0xd1, 0xd0, 0xb4, 0x12, 0x24,
+ 0xb4, 0x07, 0x94, 0xa1, 0x22, 0xf1, 0xbe, 0x01, 0x9a, 0xb6, 0x07, 0x98, 0xb2, 0xed, 0x85, 0x97,
+ 0xc8, 0x6d, 0xee, 0x5c, 0x23, 0xa7, 0x89, 0xec, 0xdb, 0x89, 0xed, 0x47, 0xf1, 0x4b, 0xf8, 0x1f,
+ 0xfc, 0x0d, 0x64, 0x3b, 0x29, 0x03, 0x0a, 0xe2, 0xcd, 0x3e, 0x3e, 0xbe, 0xbe, 0xe7, 0x9e, 0x63,
+ 0x88, 0xcd, 0x82, 0x6b, 0x2c, 0xb3, 0x46, 0xd7, 0x54, 0xb3, 0x81, 0x90, 0xc4, 0xd5, 0xdd, 0xde,
+ 0x81, 0xa8, 0x6b, 0xa1, 0xf0, 0xc8, 0xa1, 0xb3, 0xd5, 0xcd, 0x11, 0xc9, 0x0a, 0x0d, 0xf1, 0xaa,
+ 0xf1, 0xc4, 0xf4, 0x4b, 0x08, 0x90, 0x63, 0x53, 0x1b, 0x49, 0xb5, 0xbe, 0x63, 0x4f, 0x21, 0x36,
+ 0x54, 0x6b, 0x2e, 0xb0, 0x58, 0xf2, 0x0a, 0x93, 0x70, 0x12, 0x1c, 0x8e, 0xf2, 0x71, 0x8b, 0xbd,
+ 0xe7, 0x15, 0xb2, 0x67, 0xb0, 0xad, 0x51, 0x71, 0x92, 0xb7, 0x58, 0x34, 0x9c, 0x16, 0x49, 0xcf,
+ 0x71, 0xe2, 0x0e, 0xbc, 0xe0, 0xb4, 0x60, 0x2f, 0x61, 0x57, 0x48, 0x2a, 0xea, 0xd9, 0x27, 0x9c,
+ 0x53, 0x51, 0x4a, 0x8d, 0x73, 0x5b, 0x3f, 0x89, 0x1c, 0x97, 0x09, 0x49, 0x1f, 0xdc, 0xd1, 0xdb,
+ 0xee, 0x84, 0x9d, 0xc2, 0xc4, 0xde, 0xe0, 0x8a, 0x50, 0x2f, 0x39, 0xe1, 0xaf, 0x77, 0x25, 0x9a,
+ 0xa4, 0x3f, 0xe9, 0x1d, 0x8e, 0xf2, 0x7d, 0x21, 0xe9, 0xb8, 0xa3, 0xfd, 0x5c, 0x46, 0xa2, 0xb1,
+ 0xfd, 0x09, 0x55, 0xe8, 0xb5, 0xa6, 0x64, 0xe0, 0xfb, 0x13, 0xea, 0x81, 0xce, 0xe7, 0xf0, 0xbf,
+ 0x50, 0x45, 0xa3, 0x6b, 0xf7, 0x86, 0x93, 0x31, 0x74, 0xb4, 0x6d, 0xa1, 0x2e, 0x3c, 0x6a, 0x75,
+ 0x9c, 0x47, 0xc3, 0x60, 0x27, 0x3c, 0x8f, 0x86, 0x5b, 0x3b, 0xc3, 0x3c, 0xb2, 0xb4, 0xf4, 0x5b,
+ 0x00, 0xa3, 0x53, 0x49, 0x6f, 0xea, 0xaa, 0x92, 0xc4, 0xfe, 0x83, 0x50, 0x96, 0x49, 0xe0, 0xae,
+ 0x86, 0xb2, 0x64, 0x09, 0x6c, 0x99, 0x95, 0x6b, 0xc9, 0x8d, 0x2e, 0xce, 0xbb, 0x2d, 0x63, 0x10,
+ 0xcd, 0xea, 0xf2, 0xce, 0x4d, 0x2b, 0xce, 0xdd, 0x9a, 0xbd, 0x80, 0x01, 0x5f, 0xd1, 0xa2, 0xd6,
+ 0x6e, 0x2e, 0xe3, 0xe9, 0x6e, 0xe6, 0x6d, 0xcb, 0x7c, 0xf5, 0x63, 0x77, 0x96, 0xb7, 0x1c, 0x36,
+ 0x85, 0xd1, 0xdc, 0xe1, 0x84, 0x3a, 0xe9, 0xff, 0xe5, 0xc2, 0x0f, 0x1a, 0xdb, 0x07, 0x68, 0xb8,
+ 0xc6, 0x25, 0x15, 0xb2, 0x34, 0xc9, 0xc0, 0xcd, 0x6f, 0xe4, 0x91, 0xb3, 0xd2, 0xb0, 0x27, 0x30,
+ 0xb2, 0x8d, 0x14, 0x46, 0xde, 0x63, 0xb2, 0x35, 0x09, 0x0e, 0x7b, 0xf9, 0xd0, 0x02, 0x97, 0xf2,
+ 0x1e, 0xd3, 0x05, 0xc4, 0x0f, 0xcb, 0x5a, 0x05, 0x2e, 0x13, 0x81, 0x57, 0x60, 0xd7, 0x6c, 0x17,
+ 0xfa, 0x58, 0x71, 0xa9, 0x5a, 0xb5, 0x7e, 0xc3, 0x32, 0x88, 0x4a, 0x4e, 0xe8, 0xb4, 0x8e, 0xa7,
+ 0x7b, 0x99, 0x0f, 0x61, 0xd6, 0x85, 0x30, 0xbb, 0xea, 0x42, 0x98, 0x3b, 0x5e, 0x9a, 0x02, 0xbc,
+ 0xfb, 0x2c, 0xe9, 0x92, 0x38, 0xad, 0x8c, 0xad, 0x79, 0xcb, 0xd5, 0xca, 0x3f, 0xd4, 0xcf, 0xfd,
+ 0x26, 0xbd, 0x82, 0xc1, 0x89, 0xe6, 0xcb, 0xf9, 0x62, 0x63, 0x1f, 0xaf, 0x61, 0x9b, 0xb8, 0x16,
+ 0x48, 0x85, 0xd7, 0xee, 0xfa, 0x19, 0x4f, 0x1f, 0x75, 0xf3, 0x59, 0x3b, 0x96, 0xc7, 0x9e, 0xe7,
+ 0x77, 0xe9, 0xd7, 0x00, 0x7a, 0x57, 0x5c, 0x6c, 0xac, 0xe9, 0xbd, 0x0d, 0xd7, 0xde, 0xfe, 0xf6,
+ 0x46, 0xef, 0x9f, 0xde, 0xb0, 0x99, 0xa8, 0xd0, 0x18, 0x2e, 0xd0, 0xd9, 0x1c, 0xe7, 0xdd, 0xd6,
+ 0xfe, 0xb6, 0x76, 0xe9, 0x1d, 0xe8, 0x3b, 0x07, 0xc6, 0x2d, 0x66, 0x4d, 0xb0, 0x11, 0x21, 0x2e,
+ 0x04, 0x6a, 0x17, 0xe3, 0x3f, 0x46, 0xc4, 0x73, 0xd2, 0x1b, 0x88, 0xae, 0x0d, 0x6a, 0xf6, 0x18,
+ 0xfa, 0x42, 0x15, 0xeb, 0x64, 0x46, 0x42, 0x9d, 0x95, 0x6b, 0x8d, 0xe1, 0x26, 0xff, 0x7a, 0x0f,
+ 0xfd, 0x3b, 0x80, 0xb1, 0x50, 0xc5, 0xca, 0xd8, 0x2f, 0x56, 0x61, 0xfb, 0x69, 0x41, 0xa8, 0xeb,
+ 0x16, 0x39, 0x81, 0x8f, 0x43, 0xdf, 0x46, 0x33, 0x9b, 0x0d, 0x9c, 0xad, 0xaf, 0xbe, 0x07, 0x00,
+ 0x00, 0xff, 0xff, 0x70, 0x8f, 0xde, 0xf3, 0x81, 0x04, 0x00, 0x00,
}
@@ -26,12 +26,12 @@ type Repository struct {
// During project creation, `gl_repository` may not be known.
GlRepository string `protobuf:"bytes,6,opt,name=gl_repository,json=glRepository" json:"gl_repository,omitempty"`
- // The human-readable GitLab project name (e.g. gitlab-org/gitlab-ce).
- // When hashed storage is use, this associates a project name with its
+ // The human-readable GitLab project path (e.g. gitlab-org/gitlab-ce).
+ // When hashed storage is use, this associates a project path with its
// path on disk. The name can change over time (e.g. when a project is
// renamed). This is primarily used for logging/debugging at the